@@ -20,49 +20,49 @@
 Application::Application()
  : KUniqueApplication()
 {
+  m_mainWindow = new TopLevel( 0, "mainWindow" );
 }
 
 
 Application::~Application()
 {
+  delete m_mainWindow;
 }
 
 
 int Application::newInstance()
 {
   kdDebug(5004) << "Application::newInstance()" << endl;
-
-  if (mainWidget()) {
-    KWin::setOnDesktop(mainWidget()->winId(),KWin::currentDesktop());
-    KWin::setActiveWindow(mainWidget()->winId());
-  } else {
-    if (isRestored()) {
-      RESTORE(TopLevel);
-    } else {
-      TopLevel* top = new TopLevel();
-      top->show();
-    }
-  }
+  KUniqueApplication::newInstance();
 
   // process parameters...
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
+  m_mainWindow->show();
+
   if (args->isSet("clipboard"))
-    static_cast<TopLevel*>(mainWidget())->defineClipboard();
-  else {
-    if (args->count()>0) {
+  {
+    m_mainWindow->defineClipboard();
+  }
+  else
+  {
+    if (args->count()>0)
+    {
       QString phrase;
-      for (int i=0;i<args->count();i++) {
+      for (int i=0;i<args->count();i++)
+      {
         phrase += QString::fromLocal8Bit(args->arg(i));
         if (i+1 < args->count())
           phrase += " ";
       }
-      static_cast<TopLevel*>(mainWidget())->define(phrase);
-    } else
-      static_cast<TopLevel*>(mainWidget())->normalStartup();
+      m_mainWindow->define(phrase);
+    }
+    else
+    {
+      m_mainWindow->normalStartup();
+    }
   }
 
-  kdDebug(5004) << "Application::newInstance() done" << endl;
   return 0;
 }
 
