@@ -13,8 +13,11 @@
 #define APPLICATION_H
 
 #include <kuniqueapplication.h>
+#include <qguardedptr.h>
 
-#define KDICT_VERSION "0.5.5"
+#define KDICT_VERSION "0.6"
+
+class TopLevel;
 
 class Application : public KUniqueApplication
 {
@@ -28,6 +31,9 @@ class Application : public KUniqueApplication
         main window active if Kdict is already running */
     int newInstance();
 
+  private:
+    QGuardedPtr<TopLevel> m_mainWindow;
+
 };
 
 #endif
