@@ -2,7 +2,7 @@
 *                                  main.cpp
 *                             -------------------
 *
-*    Revision     : $Id: main.cpp 490685 2005-12-22 19:52:33Z ratz $
+*    Revision     : $Id: main.cpp 501833 2006-01-24 01:03:52Z ratz $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -172,7 +172,9 @@ public:
 			for( int i=0; i < args->count(); ++i){
 				urls.append(KURL::fromPathOrURL( args->arg(i)));
 			}
-			if ( args->count()==2 & urls.last().protocol() == "file" )
+			
+			// Sometimes valid filenames are not recognised by KURL::isLocalFile(), they are marked as unvalid then
+			if ( args->count()==2 & ( urls.last().isLocalFile() | !urls.last().isValid()))
 			{
 				dest=urls.last().path();
 				kmain->addTransferEx( urls.first(), dest );
