@@ -1,7 +1,7 @@
 /*
     kopetechatwindow.h - Chat Window
 
-    Copyright (c) 2002      by Olivier Goffart        <ogoffart@tiscalinet.be>
+    Copyright (c) 2002      by Olivier Goffart        <ogoffart @ kde.org>
     Copyright (c) 2004      by Martijn Klingens       <klingens@kde.org>
 
     Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>
@@ -142,9 +142,7 @@ private:
 	KAction *historyDown;
 	KAction *nickComplete;
 
-#if !KDE_IS_VERSION( 3, 1, 90 )
 	KToggleAction *mStatusbarAction;
-#endif
 
 	KAction *tabLeft;
 	KAction *tabRight;
@@ -154,6 +152,7 @@ private:
 	KToggleAction* membersLeft;
 	KToggleAction* membersRight;
 	KToggleAction* toggleMembers;
+	KToggleAction* toggleAutoSpellCheck;
 
 	KopeteEmoticonAction *actionSmileyMenu;
 	KActionMenu *actionActionMenu;
@@ -210,14 +209,25 @@ private slots:
 	void slotToggleViewMembers();
 	void slotEnableUpdateBg() { updateBg = true; }
 
+	void toggleAutoSpellChecking();
+	void slotRTFEnabled( ChatView*, bool );
+
 	void slotSetCaption( bool );
-	void slotUpdateCaptionIcons( const ChatView * );
+	void slotUpdateCaptionIcons( ChatView * );
 	void slotChatClosed();
 	void slotTabContextMenu( QWidget*, const QPoint & );
 	void slotStopAnimation( ChatView* );
 	void slotNickComplete();
 	void slotCloseChat( QWidget* );
 
+	//slots for tabs from the chatview widget
+	void updateChatState( ChatView* cv, int state );
+	void updateChatTooltip( ChatView* cv );
+	void updateChatLabel();
+
+private:
+	void updateSpellCheckAction();
+
 protected:
 	virtual void closeEvent( QCloseEvent *e );
 	virtual void windowActivationChange( bool );
