@@ -22,9 +22,13 @@
 #include <kdialogbase.h>
 #include <kabc/sound.h>
 
+#include "kopetemetacontact.h"
+
 #include "kopetegvipropswidget.h"
 #include "kopetemetalvipropswidget.h"
 
+class QButtonGroup;
+
 class CustomNotificationProps;
 class KPushButton;
 class KopeteGroupViewItem;
@@ -32,6 +36,8 @@ class KopeteMetaContactLVI;
 class KopeteAddressBookExport;
 class KURLRequester;
 
+namespace Kopete { class Contact; }
+
 class KopeteGVIProps: public KDialogBase
 {
 	Q_OBJECT
@@ -68,15 +74,26 @@ class KopeteMetaLVIProps: public KDialogBase
 		KopeteMetaContactLVI *item;
 		KopeteAddressBookExport *mExport;
 		KABC::Sound mSound;
-
+		int m_countPhotoCapable;
+		QMap<int, Kopete::Contact *> m_withPhotoContacts;
+		QString mAddressBookUid; // the currently selected addressbook UID
+		
+		Kopete::MetaContact::PropertySource selectedNameSource() const;
+		Kopete::MetaContact::PropertySource selectedPhotoSource() const;
+		Kopete::Contact* selectedNameSourceContact() const;
+		Kopete::Contact* selectedPhotoSourceContact() const;
 	private slots:
 		void slotOkClicked();
 		void slotUseCustomIconsToggled( bool on );
-		void slotHasAddressbookEntryToggled( bool on );
+		void slotClearAddresseeClicked();
 		void slotSelectAddresseeClicked();
-		void slotMergeClicked();
+		void slotExportClicked();
+		void slotImportClicked();
 		void slotFromKABCClicked();
 		void slotOpenSoundDialog( KURLRequester *requester );
+		void slotLoadNameSources();
+		void slotLoadPhotoSources();
+		void slotEnableAndDisableWidgets();
 };
 
 #endif
