@@ -120,11 +120,20 @@ k_dcop:
 	 * set all account away using the global away function
 	 */
 	void setAway();
+
+	/**
+	 * set all account away using the global away function
+	 * and set an away message
+	 */
+	void setAway( const QString &msg ) { setAway( msg, true ); }
+
 	/**
 	 * set all account away using the global away function
 	 * and set an away message.
+	 * @param away decides if the message is away/non-away
 	 */
-	void setAway(const QString &msg);
+	void setAway( const QString &msg, bool away );
+
 	/**
 	 * set Available all accountes
 	 */
@@ -135,6 +144,17 @@ k_dcop:
 	 */
 	void setAutoAway();
 
+	/**
+	 * set the global nickname if global identity is enabled.
+	 * @param nickname the new global nickname
+	 */
+	void setGlobalNickname( const QString &nickname );
+
+	/**
+	 * set the global photo if global identity is enabled.
+	 * @param photoUrl URL to the photo
+	 */
+	void setGlobalPhoto( const KURL &photoUrl );
 };
 
 #endif
