@@ -57,7 +57,7 @@
 #include "kopetecontactlist.h"
 #include "kopetecontactlistview.h"
 #include "kopetelistviewsearchline.h"
-#include "kopetemessagemanagerfactory.h"
+#include "kopetechatsessionmanager.h"
 #include "kopetepluginconfig.h"
 #include "kopetepluginmanager.h"
 #include "kopeteprefs.h"
@@ -66,14 +66,16 @@
 #include "kopeteawayaction.h"
 #include "kopeteuiglobal.h"
 #include "systemtray.h"
+#include "kopeteonlinestatusmanager.h"
+#include "kopeteeditglobalidentitywidget.h"
 
 /* KMainWindow is very broken from our point of view - it deref()'s the app
- * when the last visible KMainWindow is destroyed. But when our main window is 
- * hidden when it's in the tray,closing the last chatwindow would cause the app 
+ * when the last visible KMainWindow is destroyed. But when our main window is
+ * hidden when it's in the tray,closing the last chatwindow would cause the app
  * to quit. - Richard
  *
- * Fortunately KMainWindow checks queryExit before deref()ing the Kapplication. 
- * KopeteWindow reimplements queryExit() and only returns true if it is shutting down 
+ * Fortunately KMainWindow checks queryExit before deref()ing the Kapplication.
+ * KopeteWindow reimplements queryExit() and only returns true if it is shutting down
  * (either because the user quit Kopete, or the session manager did).
  *
  * KopeteWindow and ChatWindows are closed by session management.
@@ -81,13 +83,13 @@
  * 1) user quit - KopeteWindow::slotQuit() was called, calls KopeteApplication::quitKopete(),
  *                which closes all chatwindows and the KopeteWindow.  The last window to close
  *                shuts down the PluginManager in queryExit().  When the PluginManager has completed its
- *                shutdown, the app is finally deref()ed, and the contactlist and accountmanager 
+ *                shutdown, the app is finally deref()ed, and the contactlist and accountmanager
  *                are saved.
  *                and calling KApplication::quit()
  * 2) session   - KopeteWindow and all chatwindows are closed by KApplication session management.
  *     quit        Then the shutdown proceeds as above.
  *
- * queryClose() is honoured so group chats and chats receiving recent messages can interrupt 
+ * queryClose() is honoured so group chats and chats receiving recent messages can interrupt
  * (session) quit.
  */
 
@@ -127,7 +129,7 @@ KopeteWindow::KopeteWindow( QWidget *parent, const char *name )
 		this, SLOT(slotAccountRegistered(Kopete::Account*)));
 	connect( Kopete::AccountManager::self(), SIGNAL(accountUnregistered(const Kopete::Account*)),
 		this, SLOT(slotAccountUnregistered(const Kopete::Account*)));
-	
+
 	connect( m_autoHideTimer, SIGNAL( timeout() ), this, SLOT( slotAutoHide() ) );
 	connect( KopetePrefs::prefs(), SIGNAL( contactListAppearanceChanged() ),
 		this, SLOT( slotContactListAppearanceChanged() ) );
@@ -147,6 +149,11 @@ KopeteWindow::KopeteWindow( QWidget *parent, const char *name )
 	QPtrList<Kopete::Account>  accounts = Kopete::AccountManager::self()->accounts();
 	for(Kopete::Account *a=accounts.first() ; a; a=accounts.next() )
 		slotAccountRegistered(a);
+
+    //install an event filter for the quick search toolbar so we can
+    //catch the hide events
+    toolBar( "quickSearchBar" )->installEventFilter( this );
+
 }
 
 void KopeteWindow::initView()
@@ -171,9 +178,8 @@ void KopeteWindow::initActions()
 		0, Kopete::AccountManager::self(), SLOT( disconnectAll() ),
 		actionCollection(), "DisconnectAll" );
 
-	actionExportContacts = new KAction( i18n( "&Export Contacts..." ), "",
-																			0, this, SLOT( showExportDialog() ),
-																			actionCollection(), "ExportContacts" );
+	actionExportContacts = new KAction( i18n( "&Export Contacts..." ), "", 0, this,
+		SLOT( showExportDialog() ),actionCollection(), "ExportContacts" );
 
 	/* the connection menu has been replaced by the set status menu
 	actionConnectionMenu = new KActionMenu( i18n("Connection"),"connect_established",
@@ -190,9 +196,25 @@ void KopeteWindow::initActions()
 		this, SLOT( slotGlobalAwayMessageSelect( const QString & ) ), actionCollection(),
 		"SetAwayAll" );
 
-	actionSetAvailable = new KAction( i18n( "&Online" ),
+	selectBusy = new Kopete::AwayAction( i18n("&Busy"), SmallIcon("kopeteaway"), 0,
+					 this, SLOT( slotGlobalBusyMessageSelect( const QString & ) ), actionCollection(),
+					 "SetBusyAll" );
+
+
+	actionSetInvisible = new KAction( i18n( "&Invisible" ), "kopeteavailable", 0 ,
+		  this, SLOT( slotSetInvisibleAll() ), actionCollection(),
+		  "SetInvisibleAll" );
+
+
+
+	/*actionSetAvailable = new KAction( i18n( "&Online" ),
 		"kopeteavailable", 0 , Kopete::AccountManager::self(),
 		SLOT( setAvailableAll() ), actionCollection(),
+		"SetAvailableAll" );*/
+
+	actionSetAvailable = new Kopete::AwayAction( i18n("&Online"),
+		SmallIcon("kopeteavailable"), 0, this,
+		SLOT( slotGlobalAvailableMessageSelect( const QString & ) ), actionCollection(),
 		"SetAvailableAll" );
 
 	actionAwayMenu = new KActionMenu( i18n("&Set Status"), "kopeteaway",
@@ -200,6 +222,8 @@ void KopeteWindow::initActions()
 	actionAwayMenu->setDelayed( false );
 	actionAwayMenu->insert(actionSetAvailable);
 	actionAwayMenu->insert(selectAway);
+	actionAwayMenu->insert(selectBusy);
+	actionAwayMenu->insert(actionSetInvisible);
 	actionAwayMenu->insert(actionDisconnect);
 
 	actionPrefs = KopeteStdAction::preferences( actionCollection(), "settings_prefs" );
@@ -216,7 +240,7 @@ void KopeteWindow::initActions()
 	new KAction( i18n( "Configure &Global Shortcuts..." ), "configure_shortcuts", 0, this,
 		SLOT( slotConfGlobalKeys() ), actionCollection(), "settings_global" );
 
-	KStdAction::configureToolbars(this, SLOT(slotConfToolbar()), actionCollection(), "settings_toolbars" );
+	KStdAction::configureToolbars( this, SLOT(slotConfToolbar()), actionCollection() );
 	KStdAction::configureNotifications(this, SLOT(slotConfNotifications()), actionCollection(), "settings_notifications" );
 
 	actionShowOffliners = new KToggleAction( i18n( "Show Offline &Users" ), "viewmag", CTRL + Key_U,
@@ -241,6 +265,12 @@ void KopeteWindow::initActions()
 	resetQuickSearch->setWhatsThis( i18n( "Reset Quick Search\n"
 		"Resets the quick search so that all contacts and groups are shown again." ) );
 
+	// Edit global identity widget/bar
+	editGlobalIdentityWidget = new KopeteEditGlobalIdentityWidget(this, "editglobalBar");
+	KWidgetAction *editGlobalAction = new KWidgetAction( editGlobalIdentityWidget, i18n("Edit Global Identity Widget"), 0, 0, 0, actionCollection(), "editglobal_widget");
+	editGlobalAction->setAutoSized( true );
+
+
 	// sync actions, config and prefs-dialog
 	connect ( KopetePrefs::prefs(), SIGNAL(saved()), this, SLOT(slotConfigChanged()) );
 	slotConfigChanged();
@@ -250,7 +280,10 @@ void KopeteWindow::initActions()
 		CTRL+SHIFT+Key_I, KKey::QtWIN+CTRL+Key_I, Kopete::ChatSessionManager::self(), SLOT(slotReadMessage()) );
 
 	globalAccel->insert( QString::fromLatin1("Show/Hide Contact List"), i18n("Show/Hide Contact List"), i18n("Show or hide the contact list"),
-		CTRL+SHIFT+Key_C, KKey::QtWIN+CTRL+Key_C, this, SLOT(slotShowHide()) );
+		CTRL+SHIFT+Key_S, KKey::QtWIN+CTRL+Key_S, this, SLOT(slotShowHide()) );
+
+	globalAccel->insert( QString::fromLatin1("Set Away/Back"), i18n("Set Away/Back"), i18n("Sets away from keyboard or sets back"),
+		CTRL+SHIFT+Key_W, KKey::QtWIN+CTRL+SHIFT+Key_W, this, SLOT(slotToggleAway()) );
 
 	globalAccel->readSettings();
 	globalAccel->updateConnections();
@@ -278,6 +311,20 @@ void KopeteWindow::slotShowHide()
 	}
 }
 
+void KopeteWindow::slotToggleAway()
+{
+	Kopete::Away *mAway = Kopete::Away::getInstance();
+	if ( mAway->globalAway() )
+	{
+		Kopete::AccountManager::self()->setAvailableAll();
+	}
+	else
+	{
+		QString awayReason = mAway->getMessage( 0 );
+		slotGlobalAwayMessageSelect(awayReason);
+	}
+}
+
 void KopeteWindow::initSystray()
 {
 	m_tray = KopeteSystemTray::systemTray( this, "KopeteSystemTray" );
@@ -303,12 +350,36 @@ KopeteWindow::~KopeteWindow()
 	delete m_pluginConfig;
 }
 
+bool KopeteWindow::eventFilter( QObject* target, QEvent* event )
+{
+    KToolBar* toolBar = dynamic_cast<KToolBar*>( target );
+    KAction* resetAction = actionCollection()->action( "quicksearch_reset" );
+
+    if ( toolBar && resetAction && resetAction->isPlugged( toolBar ) )
+    {
+
+        if ( event->type() == QEvent::Hide )
+        {
+            resetAction->activate();
+            return true;
+        }
+        return KMainWindow::eventFilter( target, event );
+    }
+
+    return KMainWindow::eventFilter( target, event );
+}
+
 void KopeteWindow::loadOptions()
 {
 	KConfig *config = KGlobal::config();
 
 	toolBar("mainToolBar")->applySettings( config, "ToolBar Settings" );
 	toolBar("quickSearchBar")->applySettings( config, "QuickSearchBar Settings" );
+	toolBar("editGlobalIdentityBar")->applySettings( config, "EditGlobalIdentityBar Settings" );
+
+	// FIXME: HACK: Is there a way to do that automatic ?
+	editGlobalIdentityWidget->setIconSize(toolBar("editGlobalIdentityBar")->iconSize());
+	connect(toolBar("editGlobalIdentityBar"), SIGNAL(modechange()), editGlobalIdentityWidget, SLOT(iconSizeChanged()));
 
 	applyMainWindowSettings( config, "General Options" );
 	config->setGroup("General Options");
@@ -326,7 +397,7 @@ void KopeteWindow::loadOptions()
 	m_autoHide = p->contactListAutoHide();
 	m_autoHideTimeout = p->contactListAutoHideTimeout();
 
-	
+
 	QString tmp = config->readEntry("State", "Shown");
 	if ( tmp == "Minimized" && p->showTray())
 	{
@@ -341,6 +412,8 @@ void KopeteWindow::loadOptions()
 
 	menubarAction->setChecked( !menuBar()->isHidden() );
 	statusbarAction->setChecked( !statusBar()->isHidden() );
+	m_autoHide = p->contactListAutoHide();
+	m_autoHideTimeout = p->contactListAutoHideTimeout();
 }
 
 void KopeteWindow::saveOptions()
@@ -349,6 +422,7 @@ void KopeteWindow::saveOptions()
 
 	toolBar("mainToolBar")->saveSettings ( config, "ToolBar Settings" );
 	toolBar("quickSearchBar")->saveSettings( config, "QuickSearchBar Settings" );
+	toolBar("editGlobalIdentityBar")->saveSettings( config, "EditGlobalIdentityBar Settings" );
 
 	saveMainWindowSettings( config, "General Options" );
 
@@ -424,7 +498,7 @@ void KopeteWindow::slotContactListAppearanceChanged()
 	KopetePrefs* p = KopetePrefs::prefs();
 	m_autoHide = p->contactListAutoHide();
 	m_autoHideTimeout = p->contactListAutoHideTimeout();
-	
+
 	startAutoHideTimer();
 }
 
@@ -469,6 +543,23 @@ void KopeteWindow::slotGlobalAwayMessageSelect( const QString &awayReason )
 	Kopete::AccountManager::self()->setAwayAll( awayReason );
 }
 
+void KopeteWindow::slotGlobalBusyMessageSelect( const QString &awayReason )
+{
+	Kopete::Away::getInstance()->setGlobalAwayMessage( awayReason );
+	Kopete::AccountManager::self()->setOnlineStatus(
+			Kopete::OnlineStatusManager::Busy , awayReason );
+}
+
+void KopeteWindow::slotGlobalAvailableMessageSelect( const QString &awayReason )
+{
+	Kopete::Away::getInstance()->setGlobalAwayMessage( awayReason );
+	Kopete::AccountManager::self()->setAvailableAll( awayReason );
+}
+
+void KopeteWindow::slotSetInvisibleAll(  )
+{
+	Kopete::AccountManager::self()->setOnlineStatus( Kopete::OnlineStatusManager::Invisible  );
+}
 
 bool KopeteWindow::queryClose()
 {
@@ -501,7 +592,7 @@ bool KopeteWindow::queryExit()
 		Kopete::PluginManager::self()->shutdown();
 		return true;
 	}
-	else 
+	else
 		return false;
 }
 
@@ -515,7 +606,7 @@ void KopeteWindow::closeEvent( QCloseEvent *e )
 		// Save settings if auto-save is enabled, and settings have changed
 		if ( settingsDirty() && autoSaveSettings() )
 			saveAutoSaveSettings();
-	
+
 		if ( queryClose() ) {
 			e->accept();
 		}
@@ -576,11 +667,6 @@ void KopeteWindow::slotAccountRegistered( Kopete::Account *account )
 		SLOT( slotAccountStatusIconRightClicked( Kopete::Account *,
 		const QPoint & ) ) );
 
-	// this should be placed in contactlistview, but i am lazy to redo a new slot
-	contactlist->actionAddContact->insert(new KAction( account->accountLabel() ,
-		account->accountIcon(), 0 ,
-		contactlist, SLOT( slotAddContact() ), account));
-
 	m_accountStatusBarIcons.insert( account, sbIcon );
 	slotAccountStatusIconChanged( account->myself() );
 }
@@ -750,7 +836,7 @@ void KopeteWindow::slotAutoHide()
 
 void KopeteWindow::startAutoHideTimer()
 {
-	if ( m_autoHideTimeout > 0 && m_autoHide == true && isVisible() )
+	if ( m_autoHideTimeout > 0 && m_autoHide == true && isVisible() && KopetePrefs::prefs()->showTray())
 		m_autoHideTimer->start( m_autoHideTimeout * 1000 );
 }
 
