@@ -1,7 +1,7 @@
 /*
     videodevice.cpp  -  Kopete Video Device Low-level Support
 
-    Copyright (c) 2005 by Cláudio da Silveira Pinheiro   <taupter@gmail.com>
+    Copyright (c) 2005-2006 by Cláudio da Silveira Pinheiro   <taupter@gmail.com>
 
     Kopete    (c) 2002-2003      by the Kopete developers  <kopete-devel@kde.org>
 
@@ -36,15 +36,18 @@ namespace Kopete {
 namespace AV {
 
 VideoDevicePool *VideoDevicePool::s_self = NULL;
+__u64 VideoDevicePool::m_clients = 0;
 
 VideoDevicePool* VideoDevicePool::self()
 {
-//	kdDebug() << "libkopete (avdevice): self() called" << endl;
+	kdDebug() << "libkopete (avdevice): self() called" << endl;
 	if (s_self == NULL)
 	{
 		s_self = new VideoDevicePool;
+		if (s_self)
+			m_clients = 0;
 	}
-//	kdDebug() << "libkopete (avdevice): self() exited successfuly" << endl;
+	kdDebug() << "libkopete (avdevice): self() exited successfuly. m_clients = " << m_clients << endl;
 	return s_self;
 }
 
@@ -67,6 +70,7 @@ int VideoDevicePool::open()
 {
     /// @todo implement me
 
+	m_ready.lock();
 	if(!m_videodevice.size())
 	{
 		kdDebug() <<  k_funcinfo << "open(): No devices found. Must scan for available devices." << m_current_device << endl;
@@ -75,6 +79,7 @@ int VideoDevicePool::open()
 	if(!m_videodevice.size())
 	{
 		kdDebug() <<  k_funcinfo << "open(): No devices found. bailing out." << m_current_device << endl;
+		m_ready.unlock();
 		return EXIT_FAILURE;
 	}
 	if(m_current_device >= m_videodevice.size())
@@ -82,13 +87,15 @@ int VideoDevicePool::open()
 		kdDebug() <<  k_funcinfo << "open(): Device out of scope (" << m_current_device << "). Defaulting to the first one." << endl;
 		m_current_device = 0;
 	}
-loadConfig();
 	int isopen = m_videodevice[currentDevice()].open();
 	if ( isopen == EXIT_SUCCESS)
 	{
 		loadConfig(); // Temporary hack. The open() seems to clean the input parameters. Need to find a way to fix it.
 		
 	}
+	m_clients++;
+	kdDebug() << k_funcinfo << "Number of clients: " << m_clients << endl;
+	m_ready.unlock();
 	return isopen;
 }
 
@@ -177,9 +184,14 @@ int VideoDevicePool::setSize( int newwidth, int newheight)
 int VideoDevicePool::close()
 {
     /// @todo implement me
-	if(currentDevice() < m_videodevice.size())
+	if(m_clients)
+		m_clients--;
+	if((currentDevice() < m_videodevice.size())&&(!m_clients))
 		return m_videodevice[currentDevice()].close();
-	kdDebug() <<  k_funcinfo << "VideoDevicePool::close() Current device out of range." << endl;
+	if(m_clients)
+		kdDebug() <<  k_funcinfo << "VideoDevicePool::close() The video device is still in use." << endl;
+	if(currentDevice() >= m_videodevice.size())
+		kdDebug() <<  k_funcinfo << "VideoDevicePool::close() Current device out of range." << endl;
 	return EXIT_FAILURE;
 }
 
@@ -188,6 +200,7 @@ int VideoDevicePool::close()
  */
 int VideoDevicePool::startCapturing()
 {
+	kdDebug() <<  k_funcinfo << "startCapturing() called." << endl;
 	if(m_videodevice.size())
 		return m_videodevice[currentDevice()].startCapturing();
 	return EXIT_FAILURE;
@@ -210,7 +223,10 @@ int VideoDevicePool::stopCapturing()
  */
 float VideoDevicePool::getBrightness()
 {
+  if (currentDevice() < m_videodevice.size() )
 	return m_videodevice[currentDevice()].getBrightness();
+  else
+	return 0;
 }
 
 /*!
@@ -218,7 +234,10 @@ float VideoDevicePool::getBrightness()
  */
 float VideoDevicePool::setBrightness(float brightness)
 {
-	return m_videodevice[currentDevice()].setBrightness(brightness);
+    if (currentDevice() < m_videodevice.size() )
+	  return m_videodevice[currentDevice()].setBrightness(brightness);
+	else
+	  return 0;
 }
 
 /*!
@@ -226,7 +245,10 @@ float VideoDevicePool::setBrightness(float brightness)
  */
 float VideoDevicePool::getContrast()
 {
-	return m_videodevice[currentDevice()].getContrast();
+    if (currentDevice() < m_videodevice.size() )
+	  return m_videodevice[currentDevice()].getContrast();
+	else
+	  return 0;
 }
 
 /*!
@@ -234,7 +256,10 @@ float VideoDevicePool::getContrast()
  */
 float VideoDevicePool::setContrast(float contrast)
 {
-	return m_videodevice[currentDevice()].setContrast(contrast);
+    if (currentDevice() < m_videodevice.size() )
+	  return m_videodevice[currentDevice()].setContrast(contrast);
+	else
+	  return 0;
 }
 
 /*!
@@ -242,7 +267,10 @@ float VideoDevicePool::setContrast(float contrast)
  */
 float VideoDevicePool::getSaturation()
 {
-	return m_videodevice[currentDevice()].getSaturation();
+    if (currentDevice() < m_videodevice.size() )
+	  return m_videodevice[currentDevice()].getSaturation();
+	else
+	  return 0;
 }
 
 /*!
@@ -250,7 +278,10 @@ float VideoDevicePool::getSaturation()
  */
 float VideoDevicePool::setSaturation(float saturation)
 {
-	return m_videodevice[currentDevice()].setSaturation(saturation);
+    if (currentDevice() < m_videodevice.size() )
+	  return m_videodevice[currentDevice()].setSaturation(saturation);
+	else
+	  return 0;
 }
 
 /*!
@@ -258,7 +289,10 @@ float VideoDevicePool::setSaturation(float saturation)
  */
 float VideoDevicePool::getWhiteness()
 {
-	return m_videodevice[currentDevice()].getWhiteness();
+    if (currentDevice() < m_videodevice.size() )
+	  return m_videodevice[currentDevice()].getWhiteness();
+	else
+	  return 0;
 }
 
 /*!
@@ -266,7 +300,10 @@ float VideoDevicePool::getWhiteness()
  */
 float VideoDevicePool::setWhiteness(float whiteness)
 {
-	return m_videodevice[currentDevice()].setWhiteness(whiteness);
+    if (currentDevice() < m_videodevice.size() )
+	  return m_videodevice[currentDevice()].setWhiteness(whiteness);
+	else
+	  return 0;
 }
 
 /*!
@@ -274,7 +311,10 @@ float VideoDevicePool::setWhiteness(float whiteness)
  */
 float VideoDevicePool::getHue()
 {
-	return m_videodevice[currentDevice()].getHue();
+    if (currentDevice() < m_videodevice.size() )
+	  return m_videodevice[currentDevice()].getHue();
+	else
+	  return 0;
 }
 
 /*!
@@ -282,7 +322,10 @@ float VideoDevicePool::getHue()
  */
 float VideoDevicePool::setHue(float hue)
 {
-	return m_videodevice[currentDevice()].setHue(hue);
+    if (currentDevice() < m_videodevice.size() )
+	  return m_videodevice[currentDevice()].setHue(hue);
+	else
+	  return 0;
 }
 
 /*!
@@ -348,6 +391,27 @@ bool VideoDevicePool::setImageAsMirror(bool imageasmirror)
 	return false;
 }
 
+/*!
+    \fn VideoDevicePool::getDisableMMap()
+ */
+bool VideoDevicePool::getDisableMMap()
+{
+	if(m_videodevice.size())
+		return m_videodevice[currentDevice()].getDisableMMap();
+	return false;
+}
+
+/*!
+    \fn VideoDevicePool::setDisableMMap(bool disablemmap)
+ */
+bool VideoDevicePool::setDisableMMap(bool disablemmap)
+{
+	kdDebug() <<  k_funcinfo << "VideoDevicePool::setDisableMMap(" << disablemmap << ") called." << endl;
+	if(m_videodevice.size())
+		return m_videodevice[currentDevice()].setDisableMMap(disablemmap);
+	return false;
+}
+
 /*!
     \fn VideoDevicePool::getWorkaroundBrokenDriver()
  */
@@ -473,7 +537,7 @@ int VideoDevicePool::setInputParameters()
 }
 
 /*!
-    \fn Kopete::AV::VideoDevicePool::fillInputKComboBox(KComboBox *combobox)
+    \fn Kopete::AV::VideoDevicePool::fillDeviceKComboBox(KComboBox *combobox)
  */
 int VideoDevicePool::fillDeviceKComboBox(KComboBox *combobox)
 {
@@ -517,6 +581,67 @@ int VideoDevicePool::fillInputKComboBox(KComboBox *combobox)
 	return EXIT_FAILURE;
 }
 
+/*!
+    \fn Kopete::AV::VideoDevicePool::fillStandardKComboBox(KComboBox *combobox)
+ */
+int VideoDevicePool::fillStandardKComboBox(KComboBox *combobox)
+{
+    /// @todo implement me
+	kdDebug() <<  k_funcinfo << "fillInputKComboBox: Called." << endl;
+	combobox->clear();
+	if(m_videodevice.size())
+	{
+		if(m_videodevice[currentDevice()].inputs()>0)
+		{
+			for (unsigned int loop=0; loop < 25; loop++)
+			{
+				if ( (m_videodevice[currentDevice()].m_input[currentInput()].m_standards) & (1 << loop) )
+					combobox->insertItem(m_videodevice[currentDevice()].signalStandardName( 1 << loop));
+/*
+				case STANDARD_PAL_B1	: return V4L2_STD_PAL_B1;	break;
+				case STANDARD_PAL_G	: return V4L2_STD_PAL_G;	break;
+				case STANDARD_PAL_H	: return V4L2_STD_PAL_H;	break;
+				case STANDARD_PAL_I	: return V4L2_STD_PAL_I;	break;
+				case STANDARD_PAL_D	: return V4L2_STD_PAL_D;	break;
+				case STANDARD_PAL_D1	: return V4L2_STD_PAL_D1;	break;
+				case STANDARD_PAL_K	: return V4L2_STD_PAL_K;	break;
+				case STANDARD_PAL_M	: return V4L2_STD_PAL_M;	break;
+				case STANDARD_PAL_N	: return V4L2_STD_PAL_N;	break;
+				case STANDARD_PAL_Nc	: return V4L2_STD_PAL_Nc;	break;
+				case STANDARD_PAL_60	: return V4L2_STD_PAL_60;	break;
+				case STANDARD_NTSC_M	: return V4L2_STD_NTSC_M;	break;
+				case STANDARD_NTSC_M_JP	: return V4L2_STD_NTSC_M_JP;	break;
+				case STANDARD_NTSC_443	: return V4L2_STD_NTSC;		break; // Using workaround value because my videodev2.h header seems to not include this standard in struct __u64 v4l2_std_id
+				case STANDARD_SECAM_B	: return V4L2_STD_SECAM_B;	break;
+				case STANDARD_SECAM_D	: return V4L2_STD_SECAM_D;	break;
+				case STANDARD_SECAM_G	: return V4L2_STD_SECAM_G;	break;
+				case STANDARD_SECAM_H	: return V4L2_STD_SECAM_H;	break;
+				case STANDARD_SECAM_K	: return V4L2_STD_SECAM_K;	break;
+				case STANDARD_SECAM_K1	: return V4L2_STD_SECAM_K1;	break;
+				case STANDARD_SECAM_L	: return V4L2_STD_SECAM_L;	break;
+				case STANDARD_SECAM_LC	: return V4L2_STD_SECAM;	break; // Using workaround value because my videodev2.h header seems to not include this standard in struct __u64 v4l2_std_id
+				case STANDARD_ATSC_8_VSB	: return V4L2_STD_ATSC_8_VSB;	break; // ATSC/HDTV Standard officially not supported by V4L2 but exists in videodev2.h
+				case STANDARD_ATSC_16_VSB	: return V4L2_STD_ATSC_16_VSB;	break; // ATSC/HDTV Standard officially not supported by V4L2 but exists in videodev2.h
+				case STANDARD_PAL_BG	: return V4L2_STD_PAL_BG;	break;
+				case STANDARD_PAL_DK	: return V4L2_STD_PAL_DK;	break;
+				case STANDARD_PAL	: return V4L2_STD_PAL;		break;
+				case STANDARD_NTSC	: return V4L2_STD_NTSC;		break;
+				case STANDARD_SECAM_DK	: return V4L2_STD_SECAM_DK;	break;
+				case STANDARD_SECAM	: return V4L2_STD_SECAM;	break;
+				case STANDARD_525_60	: return V4L2_STD_525_60;	break;
+				case STANDARD_625_50	: return V4L2_STD_625_50;	break;
+				case STANDARD_ALL	: return V4L2_STD_ALL;		break;
+
+				combobox->insertItem(m_videodevice[currentDevice()].m_input[loop].name);
+				kdDebug() <<  k_funcinfo << "StandardKCombobox: Added input " << loop << ": " << m_videodevice[currentDevice()].m_input[loop].name << " (tuner: " << m_videodevice[currentDevice()].m_input[loop].hastuner << ")" << endl;*/
+			}
+			combobox->setCurrentItem(currentInput());
+			return EXIT_SUCCESS;
+		}
+	}
+	return EXIT_FAILURE;
+}
+
 /*!
     \fn Kopete::AV::VideoDevicePool::scanDevices()
  */
@@ -668,7 +793,7 @@ void VideoDevicePool::loadConfig()
 {
     /// @todo implement me
 	kdDebug() <<  k_funcinfo << "called" << endl;
-	if(hasDevices())
+	if((hasDevices())&&(m_clients==0))
 	{
 		KConfig *config = KGlobal::config();
 		config->setGroup("Video Device Settings");
@@ -688,6 +813,7 @@ void VideoDevicePool::loadConfig()
 			}
 			const QString name                = config->readEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Name")  .arg ((*vditerator).m_name ) .arg ((*vditerator).m_modelindex)), (*vditerator).m_model);
 			const int currentinput            = config->readNumEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Current input")  .arg ((*vditerator).m_name ) .arg ((*vditerator).m_modelindex)), 0);
+			const bool disablemmap            = config->readBoolEntry((QString::fromLocal8Bit ( "Model %1 Device %2 DisableMMap")  .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex)), false );
 			const bool workaroundbrokendriver = config->readBoolEntry((QString::fromLocal8Bit ( "Model %1 Device %2 WorkaroundBrokenDriver")  .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex)), false );
 			kdDebug() << k_funcinfo << "Device name: " << name << endl;
 			kdDebug() << k_funcinfo << "Device current input: " << currentinput << endl;
@@ -699,8 +825,8 @@ void VideoDevicePool::loadConfig()
 				const float brightness = config->readDoubleNumEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Input %3 Brightness").arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex) .arg (input)) , 0.5 );
 				const float contrast   = config->readDoubleNumEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Input %3 Contrast")  .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex) .arg (input)) , 0.5 );
 				const float saturation = config->readDoubleNumEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Input %3 Saturation").arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex) .arg (input)) , 0.5 );
-				const float whiteness  = config->readDoubleNumEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Input %3 Whiteness")  .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex) .arg (input)) , 0.5 );
-				const float hue        = config->readDoubleNumEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Input %3 Hue")       .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex) .arg (input)) , 0.0 );
+				const float whiteness  = config->readDoubleNumEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Input %3 Whiteness") .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex) .arg (input)) , 0.5 );
+				const float hue        = config->readDoubleNumEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Input %3 Hue")       .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex) .arg (input)) , 0.5 );
 				const bool  autobrightnesscontrast = config->readBoolEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Input %3 AutoBrightnessContrast") .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex) .arg (input)) , false );
 				const bool  autocolorcorrection    = config->readBoolEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Input %3 AutoColorCorrection")    .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex) .arg (input)) , false );
 				const bool  imageasmirror          = config->readBoolEntry((QString::fromLocal8Bit ( "Model %1 Device %2 Input %3 mageAsMirror")           .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex) .arg (input)) , false );
@@ -759,9 +885,11 @@ void VideoDevicePool::saveConfig()
 // Stores current input for the given video device
 			const QString name                   = QString::fromLocal8Bit ( "Model %1 Device %2 Name")  .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex);
 			const QString currentinput           = QString::fromLocal8Bit ( "Model %1 Device %2 Current input")  .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex);
+			const QString disablemmap            = QString::fromLocal8Bit ( "Model %1 Device %2 DisableMMap") .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex);
 			const QString workaroundbrokendriver = QString::fromLocal8Bit ( "Model %1 Device %2 WorkaroundBrokenDriver") .arg ((*vditerator).m_model ) .arg ((*vditerator).m_modelindex);
 			config->writeEntry( name,                   (*vditerator).m_name);
 			config->writeEntry( currentinput,           (*vditerator).currentInput());
+			config->writeEntry( disablemmap,            (*vditerator).getDisableMMap());
 			config->writeEntry( workaroundbrokendriver, (*vditerator).getWorkaroundBrokenDriver());
 
 			for (size_t input = 0 ; input < (*vditerator).m_input.size(); input++)
@@ -769,7 +897,7 @@ void VideoDevicePool::saveConfig()
 				kdDebug() << "Model:" << (*vditerator).m_model << ":Index:" << (*vditerator).m_modelindex << ":Input:" << input << ":Brightness: " << (*vditerator).m_input[input].getBrightness() << endl;
 				kdDebug() << "Model:" << (*vditerator).m_model << ":Index:" << (*vditerator).m_modelindex << ":Input:" << input << ":Contrast  : " << (*vditerator).m_input[input].getContrast()   << endl;
 				kdDebug() << "Model:" << (*vditerator).m_model << ":Index:" << (*vditerator).m_modelindex << ":Input:" << input << ":Saturation: " << (*vditerator).m_input[input].getSaturation() << endl;
-				kdDebug() << "Model:" << (*vditerator).m_model << ":Index:" << (*vditerator).m_modelindex << ":Input:" << input << ":Whiteness : " << (*vditerator).m_input[input].getWhiteness() << endl;
+				kdDebug() << "Model:" << (*vditerator).m_model << ":Index:" << (*vditerator).m_modelindex << ":Input:" << input << ":Whiteness : " << (*vditerator).m_input[input].getWhiteness()  << endl;
 				kdDebug() << "Model:" << (*vditerator).m_model << ":Index:" << (*vditerator).m_modelindex << ":Input:" << input << ":Hue       : " << (*vditerator).m_input[input].getHue()        << endl;
 				kdDebug() << "Model:" << (*vditerator).m_model << ":Index:" << (*vditerator).m_modelindex << ":Input:" << input << ":Automatic brightness / contrast: " << (*vditerator).m_input[input].getAutoBrightnessContrast() << endl;
 				kdDebug() << "Model:" << (*vditerator).m_model << ":Index:" << (*vditerator).m_modelindex << ":Input:" << input << ":Automatic color correction     : " << (*vditerator).m_input[input].getAutoColorCorrection() << endl;
