@@ -29,6 +29,7 @@
 #include <kaction.h>
 #include <kpopupmenu.h>
 #include <kmessagebox.h>
+#include <knotifyclient.h>
 
 #include "kabcpersistence.h"
 #include "kopetecontactlist.h"
@@ -40,6 +41,7 @@
 #include "kopetepluginmanager.h"
 #include "kopetegroup.h"
 #include "kopeteprefs.h"
+#include "kopeteutils.h"
 #include "kopeteuiglobal.h"
 #include "kopeteblacklister.h"
 #include "kopeteonlinestatusmanager.h"
@@ -57,6 +59,7 @@ public:
 	 , excludeconnect( true ), priority( 0 ), myself( 0 )
 	 , suppressStatusTimer( 0 ), suppressStatusNotification( false )
 	 , blackList( new Kopete::BlackLister( protocol->pluginId(), accountId ) )
+	 , connectionTry(0)
 	{ }
 
 
@@ -74,6 +77,7 @@ public:
 	bool suppressStatusNotification;
 	Kopete::BlackLister *blackList;
 	KConfigGroup *configGroup;
+	uint connectionTry;
 };
 
 Account::Account( Protocol *parent, const QString &accountId, const char *name )
@@ -97,6 +101,7 @@ Account::~Account()
 	while ( !d->contacts.isEmpty() )
 		delete *QDictIterator<Contact>( d->contacts );
 
+	kdDebug( 14010 ) << k_funcinfo << " account '" << d->id << "' about to emit accountDestroyed " << endl;
 	emit accountDestroyed(this);
 
 	delete d->myself;
@@ -110,8 +115,15 @@ void Account::disconnected( DisconnectReason reason )
 	if ( ( KopetePrefs::prefs()->reconnectOnDisconnect() == true && reason > Manual ) ||
 	     reason == BadPassword )
 	{
+		if(reason != BadPassword) 
+			d->connectionTry++;
 		//use a timer to allow the plugins to clean up after return
-		QTimer::singleShot(0, this, SLOT(connect()));
+		if(d->connectionTry < 3)
+			QTimer::singleShot( 0, this, SLOT(connect()));
+	}
+	if(reason== OtherClient)
+	{
+		Kopete::Utils::notifyConnectionLost(this, i18n("You have been disconnected"), i18n( "You have connected from another client or computer to the account '%1'" ).arg(d->id), i18n("Most proprietary Instant Messaging services do not allow you to connect from more than one location. Check that nobody is using your account without your permission. If you need a service that supports connection from various locations at the same time, use the Jabber protocol."));
 	}
 }
 
@@ -219,7 +231,7 @@ const QDict<Contact>& Account::contacts()
 }
 
 
-bool Account::addContact( const QString &contactId, const QString &displayName , Group *group, AddMode mode  )
+Kopete::MetaContact* Account::addContact( const QString &contactId, const QString &displayName , Group *group, AddMode mode  )
 {
 
 	if ( contactId == d->myself->contactId() )
@@ -278,12 +290,12 @@ bool Account::addContact( const QString &contactId, const QString &displayName ,
 		if ( !createContact( contactId, parentContact ) )
 		{
 			delete parentContact;
-			return false;
+			return 0L;
 		}
 	}
 
 	ContactList::self()->addMetaContact( parentContact );
-	return true;
+	return parentContact;
 }
 
 bool Account::addContact(const QString &contactId , MetaContact *parent, AddMode mode )
@@ -398,11 +410,12 @@ void Account::slotOnlineStatusChanged( Contact * /* contact */,
 		// connection's speed and your computer's speed you *will* need it.
 		d->suppressStatusNotification = true;
 		d->suppressStatusTimer.start( 5000, true );
+		//the timer is also used to reset the d->connectionTry
 	}
 
-	kdDebug(14010) << k_funcinfo << "account " << d->id << " changed status. was "
+/*	kdDebug(14010) << k_funcinfo << "account " << d->id << " changed status. was "
 	               << Kopete::OnlineStatus::statusTypeToString(oldStatus.status()) << ", is "
-	               << Kopete::OnlineStatus::statusTypeToString(newStatus.status()) << endl;
+	               << Kopete::OnlineStatus::statusTypeToString(newStatus.status()) << endl;*/
 	if ( wasOffline != isOffline )
 		emit isConnectedChanged();
 }
@@ -420,6 +433,8 @@ void Account::setAllContactsStatus( const Kopete::OnlineStatus &status )
 void Account::slotStopSuppression()
 {
 	d->suppressStatusNotification = false;
+	if(isConnected())
+		d->connectionTry=0;
 }
 
 bool Account::suppressStatusNotification() const
@@ -494,6 +509,11 @@ QString Account::pluginData( Plugin* /*plugin*/, const QString &key ) const
 	return configGroup()->readEntry(key);
 }
 
+void Account::setAway(bool away, const QString& reason)
+{
+	setOnlineStatus( OnlineStatusManager::self()->onlineStatus(protocol() , away ? OnlineStatusManager::Away : OnlineStatusManager::Online)  , reason );
+}
+
 void Account::virtual_hook( uint /*id*/, void* /*data*/)
 {
 }
