@@ -2,7 +2,7 @@
     kopetemessage.h  -  Base class for Kopete messages
 
     Copyright (c) 2002-2003 by Martijn Klingens      <klingens@kde.org>
-    Copyright (c) 2002-2004 by Olivier Goffart       <ogoffart@tiscalinet.be>
+    Copyright (c) 2002-2004 by Olivier Goffart       <ogoffart @ kde.org>
 
     Kopete    (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
 
@@ -19,25 +19,35 @@
 #ifndef __KOPETE_MESSAGE_H__
 #define __KOPETE_MESSAGE_H__
 
+#include "kopetecontact.h"
+
+#include <ksharedptr.h>
+
 #include <qptrlist.h>
 #include <qstring.h>
 #include <qdom.h>
 #include <qcolor.h>
 #include <qfont.h>
 #include <qdatetime.h>
+#include <qvaluelist.h>
+
+#include "kopete_export.h"
+
 
-class KopeteContact;
 class QDateTime;
-class KopeteMessageManager;
-struct KopeteMessagePrivate;
 
-typedef QPtrList<KopeteContact> KopeteContactPtrList;
+namespace Kopete {
+
+
+  class ChatSession;
+class Contact;
+
 
 /**
  * @author Martijn Klingens <klingens@kde.org>
- * @author Olivier Goffart <ogoffart@tiscalinet.be>
+ * @author Olivier Goffart <ogoffart @ kde.org>
  *
- * KopeteMessage represents any kind of messages shown on a chat view.
+ * Message represents any kind of messages shown on a chat view.
  *
  * The message may be a simple plaintext string, or a Richtext HTML like message,
  * this is indicated by the @ref format() flag.
@@ -46,7 +56,7 @@ typedef QPtrList<KopeteContact> KopeteContactPtrList;
  * It is recommended to use these flags, even for RichText messages, so the user can disable
  * custom colors in the chat window style.
  */
-class KopeteMessage
+class KOPETE_EXPORT Message
 {
 public:
 	/**
@@ -56,7 +66,7 @@ public:
 	 * - Internal: Messages which are not sent via the network. This is just a notification a plugin can show in a chat view
 	 * - Action: For the /me command , like on irc
 	 */
-	enum MessageDirection { Inbound = 0, Outbound = 1, Internal= 2, Action = 3 };
+	enum MessageDirection { Inbound = 0, Outbound = 1, Internal= 2 };
 
 	/**
 	 * Format of body
@@ -72,12 +82,12 @@ public:
 	enum MessageFormat{ PlainText = 0x01 , RichText =0x02 , ParsedHTML = 0x04|RichText , Crypted = 0x08|PlainText};
 
 	/**
-	 * Specifies the type of the view.
-	 * May currently be of type
-	 * - Chat: Two way chat
-	 * - Email: Single shot messaging
+	 * Specifies the type of the message.
+	 * Currently supported types are:
+	 * - Normal: a message
+	 * - Action: an IRC-style DESCRIBE action.
 	 */
-	enum MessageType { Undefined, Chat, Email };
+	enum MessageType { TypeNormal, TypeAction };
 
 	/**
 	 * Specifies the type of notification that will be sent with this message
@@ -90,90 +100,99 @@ public:
 	/**
 	 * Constructs a new empty message
 	 */
-	KopeteMessage();
+	Message();
 
 	/**
 	 * Deref and clean private object if refcount == 0
 	 */
-	~KopeteMessage();
+	~Message();
 
 	/**
 	 * Constructs a new message. See @ref setBody() to more information about the format
-	 * @param fromKC The KopeteContact that the message is coming from
-	 * @param toKC List of KopeteContacts the message is going to
+	 * @param fromKC The Contact that the message is coming from
+	 * @param toKC List of Contacts the message is going to
 	 * @param body Message body
-	 * @param direction The direction of the message, KopeteMessage::Inbound, KopeteMessage::Outbound, KopeteMessage::Internal
+	 * @param direction The direction of the message, Message::Inbound, Message::Outbound, Message::Internal
 	 * @param format Format of the message
+	 * @param requestedPlugin Requested view plugin for the message
 	 * @param type Type of the message, see @ref MessageType
 	 */
-	KopeteMessage( const KopeteContact *fromKC, const KopeteContactPtrList &toKC, const QString &body,
-		MessageDirection direction, MessageFormat format = PlainText, MessageType type = Undefined );
+	Message( const Contact *fromKC, const QPtrList<Contact> &toKC, const QString &body,
+		 MessageDirection direction, MessageFormat format = PlainText,
+		 const QString &requestedPlugin = QString::null, MessageType type = TypeNormal );
 
 	/**
 	 * Constructs a new message. See @ref setBody() to more information about the format
-	 * @param fromKC The KopeteContact that the message is coming from
-	 * @param toKC List of KopeteContacts the message is going to
+	 * @param fromKC The Contact that the message is coming from
+	 * @param toKC List of Contacts the message is going to
 	 * @param body Message body
-	 * @param direction The direction of the message, KopeteMessage::Inbound, KopeteMessage::Outbound, KopeteMessage::Internal
+	 * @param direction The direction of the message, Message::Inbound, Message::Outbound, Message::Internal
 	 * @param format Format of the message
+	 * @param requestedPlugin Requested view plugin for the message
 	 * @param type Type of the message, see @ref MessageType
 	 */
-	KopeteMessage( const KopeteContact *fromKC, const KopeteContact *toKC, const QString &body,
-		MessageDirection direction, MessageFormat format = PlainText, MessageType type = Undefined );
-
+	Message( const Contact *fromKC, const Contact *toKC, const QString &body,
+		 MessageDirection direction, MessageFormat format = PlainText,
+		 const QString &requestedPlugin = QString::null, MessageType type = TypeNormal );
 
 	/**
 	 * Constructs a new message. See @ref setBody() to more information about the format
-	 * @param fromKC The KopeteContact that the message is coming from
-	 * @param toKC List of KopeteContacts the message is going to
+	 * @param fromKC The Contact that the message is coming from
+	 * @param toKC List of Contacts the message is going to
 	 * @param body Message body
 	 * @param subject The subject of the message
-	 * @param direction The direction of the message, KopeteMessage::Inbound, KopeteMessage::Outbound, KopeteMessage::Internal
+	 * @param direction The direction of the message, Message::Inbound, Message::Outbound, Message::Internal
 	 * @param format Format of the message
+	 * @param requestedPlugin Requested view plugin for the message
 	 * @param type Type of the message, see @ref MessageType
 	 */
-	KopeteMessage( const KopeteContact *fromKC, const KopeteContactPtrList &toKC, const QString &body,
-		const QString &subject, MessageDirection direction, MessageFormat format = PlainText, MessageType type = Undefined );
+	Message( const Contact *fromKC, const QPtrList<Contact> &toKC, const QString &body,
+		 const QString &subject, MessageDirection direction, MessageFormat format = PlainText,
+		 const QString &requestedPlugin = QString::null, MessageType type = TypeNormal );
 
 	/**
 	 * Constructs a new message. See @ref setBody() to more information about the format
 	 * @param timeStamp Timestamp for the message
-	 * @param fromKC The KopeteContact that the message is coming from
-	 * @param toKC List of KopeteContacts the message is going to
+	 * @param fromKC The Contact that the message is coming from
+	 * @param toKC List of Contacts the message is going to
 	 * @param body Message body
-	 * @param direction The direction of the message, KopeteMessage::Inbound, KopeteMessage::Outbound, KopeteMessage::Internal
+	 * @param direction The direction of the message, Message::Inbound, Message::Outbound, Message::Internal
 	 * @param format Format of the message
+	 * @param requestedPlugin Requested view plugin for the message
 	 * @param type Type of the message, see @ref MessageType
 	 */
-	KopeteMessage( const QDateTime &timeStamp, const KopeteContact *fromKC, const KopeteContactPtrList &toKC,
-		const QString &body, MessageDirection direction, MessageFormat format = PlainText, MessageType type = Undefined );
+	Message( const QDateTime &timeStamp, const Contact *fromKC, const QPtrList<Contact> &toKC,
+		 const QString &body, MessageDirection direction, MessageFormat format = PlainText,
+		 const QString &requestedPlugin = QString::null, MessageType type = TypeNormal );
 
 	/**
 	 * Constructs a new message. See @ref setBody() to more information about the format
 	 * @param timeStamp Timestamp for the message
-	 * @param fromKC The KopeteContact that the message is coming from
-	 * @param toKC List of KopeteContacts the message is going to
+	 * @param fromKC The Contact that the message is coming from
+	 * @param toKC List of Contacts the message is going to
 	 * @param body Message body
 	 * @param subject The subject of the message
-	 * @param direction The direction of the message, KopeteMessage::Inbound, KopeteMessage::Outbound, KopeteMessage::Internal
+	 * @param direction The direction of the message, Message::Inbound, Message::Outbound, Message::Internal
 	 * @param format Format of the message
+	 * @param requestedPlugin Requested view plugin for the message
 	 * @param type Type of the message, see @ref MessageType
 	 */
-	KopeteMessage( const QDateTime &timeStamp, const KopeteContact *fromKC, const KopeteContactPtrList &toKC,
+	Message( const QDateTime &timeStamp, const Contact *fromKC, const QPtrList<Contact> &toKC,
 		const QString &body, const QString &subject, MessageDirection direction,
-		MessageFormat format = PlainText, MessageType type = Undefined );
+		MessageFormat format = PlainText, const QString &requestedPlugin = QString::null,
+		MessageType type = TypeNormal );
 
 	/**
 	 * Copy constructor.
 	 * Just adds a reference, doesn't actually copy.
 	 */
-	KopeteMessage( const KopeteMessage &other );
+	Message( const Message &other );
 
 	/**
 	 * Assignment operator
 	 * Just like the copy constructor it just refs and doesn't copy.
 	 */
-	KopeteMessage & operator=( const KopeteMessage &other );
+	Message & operator=( const Message &other );
 
 	/**
 	 * Accessor method for the timestamp of the message
@@ -182,22 +201,28 @@ public:
 	QDateTime timestamp() const;
 
 	/**
-	 * Accessor method for the KopeteContact that sent this message
-	 * @return The KopeteContact who sent this message
+	 * Accessor method for the Contact that sent this message
+	 * @return The Contact who sent this message
 	 */
-	const KopeteContact * from() const;
+	const Contact * from() const;
 
 	/**
-	 * Accessor method for the KopeteContacts that this message was sent to
-	 * @return Pointer list of the KopeteContacts this message was sent to
+	 * Accessor method for the Contacts that this message was sent to
+	 * @return Pointer list of the Contacts this message was sent to
 	 */
-	KopeteContactPtrList to() const;
+	QPtrList<Contact> to() const;
 
 	/**
 	 * @return the @ref MessageType of this message
 	 */
 	MessageType type() const;
 
+	/**
+	 * @return the view plugin you would prefer to use to read this message. If
+	 *	null, Kopete will use the user's preferred plugin.
+	 */
+	QString requestedPlugin() const;
+
 	/**
 	 * Accessor method for the foreground color
 	 * @return The message's foreground color
@@ -295,24 +320,24 @@ public:
 	QString parsedBody() const;
 
 	/**
-	 * Get the related kopete message manager.
+	 * Get the related  message manager.
 	 * If it is not set, returns 0L.
 	 *
-	 * The @ref KopeteMessageManager is only set if the message is already passed by the manager.
+	 * The @ref ChatSession is only set if the message is already passed by the manager.
 	 * We should trust this only in aboutToSend/aboutToReceive signals
 	 */
-	 KopeteMessageManager *manager() const ;
+	 ChatSession *manager() const ;
 
 	 /**
-	  * set the kopetemessagemanager for this message.
+	  * set the messagemanager for this message.
 	  * should be only used by the manager itself
 	  */
-	 void setManager(KopeteMessageManager *);
+	 void setManager(ChatSession *);
 
 	/**
 	 * get a XML version of this message
 	 */
-	const QDomDocument asXML() const;
+	const QDomDocument asXML();
 
 	/**
 	 * Enables the use of a background for a message
@@ -332,8 +357,11 @@ public:
 	 */
 	void setRtfOverride( bool enable );
 
+
+public:  /* static helpers */
+
 	/**
-	* Unescapes a string, removing XML entity references
+	* Unescapes a string, removing XML entity references and return a plein text.
 	*
 	* @param xml The string you want to unescape
 	*/
@@ -341,11 +369,11 @@ public:
 
 	/**
 	 * @brief Transform a pleintext message to an html.
-	 * it escape main entity like &gt; &lt; add some &lt;br /&gt; or &amp;nbsp
+	 * it escape main entity like &gt; &lt; add some &lt;br /&gt; or &amp;nbsp;
 	 */
 	static QString escape( const QString & );
 
-	
+
 	/**
 	 * Helper function to decode a string. Whatever returned here is *nearly guarenteed* to
 	 * be parseable by the XML engine.
@@ -357,26 +385,33 @@ public:
 	 *	provided. If a guess has to be taken, success will be false.
 	 */
 	static QString decodeString( const QCString &message,
-		const QTextCodec *providedCodec = 0L, bool *success = 0L );
+ 		const QTextCodec *providedCodec = 0L, bool *success = 0L );
+
+	
+	/**
+	 * @internal
+	 * this function will clear the cache of metacontact photo.
+	 * it is called when the photo of a contact change.
+	 */
+	static void clearImageCache();
 
 private:
 	/**
-	 * Helper for constructors
-	 */
-	void init( const QDateTime &timeStamp, const KopeteContact *from, const KopeteContactPtrList &to,
-		const QString &body, const QString &subject, MessageDirection direction, MessageFormat f, MessageType type );
-
-	/**
-	 * KopeteMessage is implicitly shared.
+	 * Message is implicitly shared.
 	 * Detach the instance when modifying data.
 	 */
 	void detach();
 
-	KopeteMessagePrivate *d;
+	class Private;
+	KSharedPtr<Private> d;
 
 	static QString parseLinks( const QString &message, MessageFormat format );
+
+	QDomElement contactNode( QDomDocument doc, const Contact *contact );
 };
 
+}
+
 #endif
 
 // vim: set noet ts=4 sts=4 sw=4:
