@@ -2,11 +2,11 @@
     kopetemetacontact.h - Kopete Meta Contact
 
     Copyright (c) 2002-2003 by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002      by Duncan Mac-Vicar Prett <duncan@kde.org>
-    Copyright (c) 2002-2003 by Olivier Goffart        <ogoffart@tiscalinet.be>
+    Copyright (c) 2002-2005 by Duncan Mac-Vicar Prett <duncan@kde.org>
+    Copyright (c) 2002-2005 by Olivier Goffart        <ogoffart @ kde.org>
     Copyright (c) 2003      by Will Stephenson        <will@stevello.free-online.co.uk>
 
-    Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>
+    Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -18,26 +18,29 @@
     *************************************************************************
 */
 
-#ifndef __kopetemetacontact_h__
-#define __kopetemetacontact_h__
+#ifndef kopetemetacontact_h__
+#define kopetemetacontact_h__
 
-#include <qdom.h>
-#include <qobject.h>
+#include "kopetecontactlistelement.h"
 #include <qptrlist.h>
+#include <qstring.h>
 
-#include <kabc/addressbook.h>
 #include <kdemacros.h>
+#include "kopete_export.h"
 
-#include "kopetecontact.h"
 #include "kopetenotifydataobject.h"
+#include "kopetecontactlistelement.h"
 #include "kopeteonlinestatus.h"
-#include "kopeteplugindataobject.h"
 
 class QDomNode;
 
 class KURL;
 
-struct KopeteMetaContactPrivate;
+namespace Kopete {
+
+
+class Plugin;
+class Group;
 
 /**
  * @author Will Stephenson <will@stevello.free-online.co.uk>
@@ -48,9 +51,9 @@ struct KopeteMetaContactPrivate;
  * A metacontact represent a person. This is a kind of entry to
  * the contactlist. All information of a contact is contained in
  * the metacontact. Plugins can store data in it with all
- * @ref KopetePluginData methods
+ * @ref ContactListElement methods
  */
-class KopeteMetaContact : public KopetePluginDataObject, public KopeteNotifyDataObject
+class KOPETE_EXPORT MetaContact : public ContactListElement, public NotifyDataObject
 {
 	Q_OBJECT
 
@@ -59,49 +62,251 @@ class KopeteMetaContact : public KopetePluginDataObject, public KopeteNotifyData
 	Q_PROPERTY( QString statusIcon READ statusIcon )
 	Q_PROPERTY( bool isOnline READ isOnline )
 	Q_PROPERTY( bool isReachable READ isReachable )
-	Q_PROPERTY( bool isTopLevel READ isTopLevel )
+	Q_PROPERTY( bool isTemporary READ isTemporary )
 	Q_PROPERTY( bool canAcceptFiles READ canAcceptFiles )
+	//Q_PROPERTY( ulong idleTime READ idleTime )
 	Q_PROPERTY( QString metaContactId READ metaContactId WRITE setMetaContactId )
-	Q_PROPERTY( bool trackChildNameChanges READ trackChildNameChanges WRITE setTrackChildNameChanges )
+	Q_PROPERTY( bool photoSyncedWithKABC READ isPhotoSyncedWithKABC WRITE setPhotoSyncedWithKABC )
 
 public:
-	enum GroupSyncMode { SyncGroups, DontSyncGroups };
+	/** 
+	 * Enumeration of possible sources for a property (which may be
+	 * photos, see setPhotoSource() for instance).
+	 */
+	enum PropertySource { 
+		SourceContact /**< Data comes from the contact itself. */, 
+		SourceKABC /**< Data comes from KABC (addressbook). */, 
+		SourceCustom /**< Data comes from somewhere else. */
+	};
 
-	KopeteMetaContact();
-	~KopeteMetaContact();
+	/**
+	 * constructor
+	 */
+	MetaContact();
+	/**
+	 * destructor
+	 */
+	~MetaContact();
+
+	/**
+	 * @brief Returns this metacontact's ID.
+	 *
+	 * Every metacontact has a unique id, set by  when creating the contact, or reading the contactlist
+	 * TODO: make it real
+	 */
+	QString metaContactId() const;
+
+	/**
+	 * @brief Add or change the link to a KDE addressbook (KABC) Addressee.
+	 * FIXME: Use with care.  You could create 1 to many relationships with the current implementation
+	 */
+	void setMetaContactId( const QString& newMetaContactId );
 
 	/**
 	 * @brief Retrieve the list of contacts that are part of the meta contact
 	 */
-	QPtrList<KopeteContact> contacts() const;
+	QPtrList<Contact> contacts() const;
 
 	/**
-	 * @brief Add a brand new contact to the meta contact.  Updates KABC
-	 * @param c The KopeteContact being added
+	 * @brief The groups the contact is stored in
 	 */
-	void addContact( KopeteContact *c );
+	QPtrList<Group> groups() const;
 
 	/**
-	 * Find the KopeteContact to a given contact. If contact
+	 * Find the Contact to a given contact. If contact
 	 * is not found, a null pointer is returned.
+	 * if @p protocolId or @p accountId are null, it is searched over all protocols/accounts
 	 */
-	KopeteContact *findContact( const QString &protocolId, const QString &accountId, const QString &contactId );
+	Contact *findContact( const QString &protocolId, const QString &accountId, const QString &contactId );
+
+	/**
+	 * @brief Set the source of metacontact displayName
+	 *
+	 * This method selects the display name source for one
+	 * of the sources defined in @ref PropertySource
+	 *
+	 * @see PropertySource
+	 */
+	void setDisplayNameSource(PropertySource source);
+
+	/**
+	 * @brief get the source of metacontact display name
+	 *
+	 * This method obtains the current name source for one
+	 * of the sources defined in @ref PropertySource
+	 *
+	 * @see PropertySource
+	 */
+	PropertySource displayNameSource() const;
+
+	/**
+	 * @brief Set the source of metacontact photo
+	 *
+	 * This method selects the photo source for one
+	 * of the sources defined in @ref PropertySource
+	 *
+	 * @see PropertySource
+	 */
+	void setPhotoSource(PropertySource source);
+
+	/**
+	 * @brief get the source of metacontact photo
+	 *
+	 * This method obtains the current photo source for one
+	 * of the sources defined in @ref PropertySource
+	 *
+	 * @see PropertySource
+	 */
+	PropertySource photoSource() const;
+
+	/**
+	 * @brief the display name showed in the contactlist window
+	 *
+	 * The displayname is the name which should be shown almost everywere to
+	 * represent the metacontact.  (in the contactlist, in the chatwindow, ....)
+	 *
+	 * This is a kind of alias, set by the kopete user, as opposed to a nickname
+	 * set by the contact itself.
+	 *
+	 * If the protocol support alias serverside, the metacontact displayname
+	 * should probably be syncronized with the alias on the server.
+	 *
+	 * This displayName is obtained from the source set with @ref setDisplayNameSource
+	 */
+	QString displayName() const;
+
+	/**
+	 * @brief the photo showed in the contactlist window
+	 *
+	 * Returns a image for the metacontact. If the metacontact photo source is
+	 * the KDE addressbook. it will return the picture stored in the addressbook
+	 * It can also use a subcontact as the photo source.
+	 *
+	 * This photo is obtained from the source set with @ref setPhotoSource
+	 */
+	QImage photo() const;
+
+	/**
+	 * @brief Set the custom displayName.
+	 *
+	 * This display name is used when name source is Custom
+	 * this metohd may emit @ref displayNameChanged signal.
+	 * And will call @ref Kopete::Contact::sync
+	 *
+	 * @see displayName()
+	 * @see displayNameSource()
+	 */
+	void setDisplayName( const QString &name );
+
+	/**
+	 * @brief Returns the custom display name
+	 *
+	 * @see displayName()
+	 * @see displayNameSource()
+	 */
+	QString customDisplayName() const;
+
+	/**
+	 * @brief Returns the custom display name
+	 *
+	 * @see displayName()
+	 * @see displayNameSource()
+	 */
+	KURL customPhoto() const;
+
+
+	/**
+	 * @brief Set the custom photo.
+	 *
+	 * This photo is used when photo source is set toCustom
+	 * this metohd may emit @ref photoChanged signal.
+	 *
+	 * @see photo()
+	 * @see photoSource()
+	 */
+	void setPhoto( const KURL &url );
+
+	/**
+	 * @brief get the subcontact being tracked for its displayname (null if not set)
+	 *
+	 * The MetaContact will adjust its displayName() every time the
+	 * "nameSource" changes its nickname property.
+	 */
+	Contact *displayNameSourceContact() const;
+
+	/**
+	 * @brief set the subcontact whose name is to be tracked (set to null to disable tracking)
+	 * @see nameSource
+	 */
+	void setDisplayNameSourceContact( Contact* contact );
+
+	/**
+	 * @brief get the subcontact being tracked for its photo
+	 */
+	Contact *photoSourceContact() const;
+
+	/**
+	 * @brief set the subcontact to use for SourceContact source
+	 */
+	void setPhotoSourceContact( Contact* contact );
+
+	/**
+	 * @return true if when a subcontact change his photo, the photo will be set to the kabc contact.
+	 */
+	bool isPhotoSyncedWithKABC() const;
+
+	/**
+	 * Set if the photo should be synced with the adressbook when the photosource change his photo
+	 *
+	 * If  \p b is true, the photo will be synced immediatly if possible
+	 */
+	void setPhotoSyncedWithKABC(bool b);
+
+
+	/**
+	 * Temporary contacts will not be serialized.
+	 * If they are added to the contactlist, they appears in a special "Not in your contactlist" group.
+	 * (the @ref Group::temporary  group)
+	 */
+	bool isTemporary() const;
+
+	/**
+	 * @brief Add a contact which has just been deserialised to the meta contact
+	 * @param c The Contact being added
+	 */
+	void addContact( Contact *c );
+
+	/**
+	 * @brief remove the contact from this metacontact
+	 *
+	 * set 'deleted' to true if the Contact is already deleted
+	 *
+	 * @param c is the contact to remove
+	 * @param deleted : if it is false, it will disconnect the old contact, and call some method.
+	 */
+	void removeContact( Contact *c , bool deleted = false );
+
+	/**
+	 * @return the preferred child Contact for communication, or 0 if none is suitable (all unreachable).
+	 */
+	Contact *preferredContact();
+
 	/**
 	 * @brief The name of the icon associated with the contact's status
+	 * @todo improve with OnlineStatus
 	 */
-	virtual QString statusIcon() const;
+	QString statusIcon() const;
 
 	/**
 	 * @brief The status string of the contact
 	 *
 	 * @see @ref status()
+	 * @todo improve with OnlineStatus
 	 */
 	QString statusString() const;
 
 	/**
 	 * Returns whether this contact can be reached online for at least one
-	 * protocol. Protocols are processed in loading order.
-	 * FIXME: Make that user preference order!
 	 * FIXME: Make that an enum, because status can be unknown for certain
 	 *        protocols
 	 */
@@ -118,14 +323,14 @@ public:
 	 * Online means at least one sub-contact is online, away means at least
 	 * one is away, but nobody is online and offline speaks for itself
 	 */
-	KopeteOnlineStatus::OnlineStatus status() const;
+	OnlineStatus::StatusType status() const;
 
 	/**
 	 * Like isOnline, but returns true even if the contact is not online, but
 	 * can be reached trough offline-messages.
 	 * it it return false, you are unable to open a chatwindow
-	 * FIXME: Here too, use preference order, not append order!
-	 * FIXME: Here too an enum.
+	 * @todo : Here too, use preference order, not append order!
+	 * @todo : Here too an enum.
 	 */
 	bool isReachable() const;
 
@@ -134,50 +339,13 @@ public:
 	 */
 	unsigned long int idleTime() const;
 
-	/**
-	 * @return the display name showed in the contactlist window, or in the chatwindow
-	 */
-	QString displayName() const;
-	/**
-	 * @brief Set the displayName.
-	 *
-	 * this metohd may emit @ref displayNameChanged signal.
-	 * If @ref trackChildNameChanges was true, this will automatically set it to false
-	 */
-	void setDisplayName( const QString &name );
-
-	/**
-	 * @brief get the tracking of contact names
-	 *
-	 * The MetaContact will adjust its displayName() every time the contact
-	 * inside changes its name.
-	 * This should only work for MCs with exactly ONE contact inside in order
-	 * to not confuse users (think about 4 subcontacts and what happens if one
-	 * changes nickname...)
-	 */
-	bool trackChildNameChanges() const;
-	/**
-	 * @brief set if the metacontact displayname follow subcontacts displayname
-	 *
-	 * When setting it to true, it will refresh the dysplayname to the subcontactone instentaneous,
-	 * and each time the contact change.
-	 *
-	 * Note that this method has an effect only if there is exactly one subcontact.
-	 *
-	 * @see @ref trackChildNameChanges , @ref setDisplayName
-	 */
-	void setTrackChildNameChanges( bool track );
-
-	/**
-	 * @brief The groups the contact is stored in
-	 */
-	KopeteGroupList groups() const;
-
 	/**
 	 * Return a XML representation of the metacontact
 	 * @internal
+	 * @param minimal When true, it doesn't save the
+	 * plugins, groups and notification data. False by default.
 	 */
-	const QDomElement toXML();
+	const QDomElement toXML(bool minimal = false);
 
 	/**
 	 * Creates a metacontact from XML
@@ -188,133 +356,44 @@ public:
 	 */
 	bool fromXML( const QDomElement& cnode );
 
-	/**
-	 * Temporary contacts will not be serialized.
-	 * If they are added to the contactlist, they appears in a special "Not in your contactlist" group.
-	 * (the @ref KopeteGroup::temporary  group)
-	 */
-	bool isTemporary() const;
-
-	/**
-	 * @brief Return true if the contact is shown at toplevel.
-	 * You may also check if @ref groups() contains @ref KopeteGroup::topLevel()
-	 */
-	bool isTopLevel() const;
-
-	/**
-	 * @brief Returns this metacontact's ID.
-	 *
-	 * Every metacontact has a unique id, set by kopete when creating the contact, or reading the contactlist
-	 */
-	QString metaContactId() const;
-
-	/**
-	 * @brief Add or change the link to a KDE addressbook (KABC) Addressee.
-	 * FIXME: Use with care.  You could create 1 to many relationships with the current implementation
-	 */
-	void setMetaContactId( const QString& newMetaContactId );
-
 	/**
 	 * Get or set a field for the KDE address book backend. Fields not
-	 * registered during the call to KopetePlugin::addressBookFields()
+	 * registered during the call to Plugin::addressBookFields()
 	 * cannot be altered!
 	 *
-	 * @param p The KopetePlugin by which uses this field
+	 * @param p The Plugin by which uses this field
 	 * @param app refers to the application id in the libkabc database.
 	 * This should be a standardized format to make sense in the address
-	 * book in the first place - if you could use "kopete" as application
+	 * book in the first place - if you could use "" as application
 	 * then probably you should use the plugin data API instead of the
 	 * address book fields.
+	 * @param key The name of the address book field to get or set
 	 *
-	 * FIXME: In the code the requirement that fields are registered first
+	 * @todo: In the code the requirement that fields are registered first
 	 *        is already lifted, but the API needs some review before we
 	 *        can remove it here too.
 	 *        Probably it requires once more some rewrites to get it working
 	 *        properly :( - Martijn
 	 */
-	QString addressBookField( KopetePlugin *p, const QString &app, const QString &key ) const;
-
-public slots:
-
-	/**
-	 * @brief Move a contact from one group to another.
-	 */
-	void moveToGroup( KopeteGroup *from, KopeteGroup *to, GroupSyncMode syncMode = SyncGroups );
-
-	/**
-	 * @brief Remove a contact from one group
-	 */
-	void removeFromGroup( KopeteGroup *from, GroupSyncMode syncMode = SyncGroups );
-
-	/**
-	 * @brief Add a contact to another group.
-	 */
-	void addToGroup( KopeteGroup *to, GroupSyncMode syncMode = SyncGroups );
-
-	/**
-	 * @brief remove the contact from this metacontact
-	 *
-	 * set 'deleted' to true if the KopeteContact is already deleted
-	 *
-	 * @param c is the contact to remove
-	 * @param deleted : if it is false, it will disconnect the old contact, and call some method.
-	 */
-	void removeContact( KopeteContact *c , bool deleted = false );
-
-	/**
-	 * @brief Set if this is a temporary contact. (see @ref isTemporary)
-	 *
-	 * @param b if the contact is or not temporary
-	 * @param group if the contact was temporary and b is true, then the contact will be moved to this group.
-	 *  if group is null, it will be moved to top-level
-	 */
-	void setTemporary( bool b = true ,KopeteGroup *group = 0L );
+	QString addressBookField( Plugin *p, const QString &app, const QString &key ) const;
 
 	/**
 	 * @brief set an address book field
 	 *
 	 * @see also @ref addressBookField()
-	 * @param p The KopetePlugin by which uses this field
+	 * @param p The Plugin by which uses this field
+	 * @param app The application ID in the KABC database
+	 * @param key The name of the address book field to set
+	 * @param value The value of the address book field to set
 	 */
-	void setAddressBookField( KopetePlugin *p, const QString &app, const QString &key, const QString &value );
+	void setAddressBookField( Plugin *p, const QString &app, const QString &key, const QString &value );
 
-	/**
-	 * @brief Contact another user.
-	 *
-	 * Depending on the config settings, call sendMessage() or
-	 * startChat()
-	 *
-	 * returns the KopeteContact that was chosen as the preferred
-	 */
-	KopeteContact *execute();
-
-	/**
-	 * @brief Send a single message, classic ICQ style.
-	 *
-	 * The actual sending is done by the KopeteContact, but the meta contact
-	 * does the GUI side of things.
-	 * This is a slot to allow being called easily from e.g. a GUI.
-	 *
-	 * returns the KopeteContact that was chosen as the preferred
-	 */
-	KopeteContact *sendMessage();
-
-	/**
-	 * @brief Start a chat in a persistent chat window
-	 *
-	 * Like sendMessage, but this time a full-blown chat will be opened.
-	 * Most protocols can't distinguish between the two and are either
-	 * completely session based like MSN or completely message based like
-	 * ICQ the only true difference is the GUI shown to the user.
-	 *
-	 * returns the KopeteContact that was chosen as the preferred
-	 */
-	KopeteContact *startChat();
+public slots:
 
 	/**
 	 * @brief Send a file to this metacontact
 	 *
-	 * This is the KopeteMetaContact level slot for sending files. It may be called through the
+	 * This is the MetaContact level slot for sending files. It may be called through the
 	 * "Send File" entry in the GUI, or over DCOP. If the function is called through the GUI,
 	 * no parameters are sent and they assume default values. This slot calls the slotSendFile
 	 * with identical params of the highest ranked contact capable of sending files (if any)
@@ -327,39 +406,84 @@ public slots:
 	 */
 	void sendFile( const KURL &sourceURL, const QString &altFileName = QString::null,
 		unsigned long fileSize = 0L );
+signals:
+	/**
+	 * This metaContact is going to be saved to the contactlist. Plugins should
+	 * connect to this signal to update data with setPluginData()
+	 */
+	void aboutToSave( Kopete::MetaContact *metaContact );
 
 	/**
-	 * @brief Change the KABC data associated with this metacontact
+	 * One of the subcontacts' idle status has changed.  As with online status,
+	 * this can occur without the metacontact changing idle state
+	 */
+	void contactIdleStateChanged( Kopete::Contact *contact );
+
+
+public slots:
+
+	/**
+	 * @brief Move a contact from one group to another.
+	 */
+	void moveToGroup( Kopete::Group *from, Kopete::Group *to );
+
+	/**
+	 * @brief Remove a contact from one group
+	 */
+	void removeFromGroup( Kopete::Group *from );
+
+	/**
+	 * @brief Add a contact to another group.
+	 */
+	void addToGroup( Kopete::Group *to );
+
+	/**
+	 * @brief Set if this is a temporary contact. (see @ref isTemporary)
 	 *
-	 * The KABC exposed data changed, so change it in KABC
+	 * @param b if the contact is or not temporary
+	 * @param group if the contact was temporary and b is true, then the contact will be moved to this group.
+	 *  if group is null, it will be moved to top-level
 	 */
-	void updateKABC();
+	void setTemporary( bool b = true, Kopete::Group *group = 0L );
 
 	/**
-	 * @brief Remove any KABC data for this meta contact
+	 * @brief Contact another user.
+	 *
+	 * Depending on the config settings, call sendMessage() or
+	 * startChat()
+	 *
+	 * returns the Contact that was chosen as the preferred
 	 */
-	void removeKABC();
-	
-	/**
-	 * Check for any new addresses added to this contact's KABC entry
-	 * and prompt if they should be added in Kopete too.
-	 * @return whether any contacts were added from KABC.
-	 */
-	bool syncWithKABC();
+	Contact *execute();
 
 	/**
-	 * @return the preferred child KopeteContact for communication, or 0 if none is suitable (all unreachable).
+	 * @brief Send a single message, classic ICQ style.
+	 *
+	 * The actual sending is done by the Contact, but the meta contact
+	 * does the GUI side of things.
+	 * This is a slot to allow being called easily from e.g. a GUI.
+	 *
+	 * returns the Contact that was chosen as the preferred
 	 */
-	KopeteContact *preferredContact();
+	Contact *sendMessage();
+
+	/**
+	 * @brief Start a chat in a persistent chat window
+	 *
+	 * Like sendMessage, but this time a full-blown chat will be opened.
+	 * Most protocols can't distinguish between the two and are either
+	 * completely session based like MSN or completely message based like
+	 * ICQ the only true difference is the GUI shown to the user.
+	 *
+	 * returns the Contact that was chosen as the preferred
+	 */
+	Contact *startChat();
+
 signals:
 	/**
 	 *  @brief The MetaContact online status changed
-	 *
-	 * Do *NOT* emit this signal directly, unless you also update the
-	 * cache m_onlineStatus value! In all other cases, just call
-	 * updateOnlineStatus() instead.
 	 */
-	void onlineStatusChanged( KopeteMetaContact *contact, KopeteOnlineStatus::OnlineStatus status );
+	void onlineStatusChanged( Kopete::MetaContact *contact, Kopete::OnlineStatus::StatusType status );
 
 	/**
 	 * @brief A contact's online status changed
@@ -368,58 +492,51 @@ signals:
 	 * change his status without changing MetaContact status. It is mainly used to update the small icons
 	 * in the contactlist
 	 */
-	void contactStatusChanged( KopeteContact *contact, const KopeteOnlineStatus &status );
+	void contactStatusChanged( Kopete::Contact *contact, const Kopete::OnlineStatus &status );
 
 	/**
 	 * @brief The meta contact's display name changed
 	 */
 	void displayNameChanged( const QString &oldName, const QString &newName );
 
+	/**
+	 * @brief The meta contact's photo changed
+	 */
+	void photoChanged();
+
 	/**
 	 * @brief  The contact was moved
 	 */
-	void movedToGroup( KopeteMetaContact *contact, KopeteGroup *from, KopeteGroup *to );
+	void movedToGroup( Kopete::MetaContact *contact, Kopete::Group *from, Kopete::Group *to );
 
 	/**
 	 * @brief The contact was removed from group
 	 */
-	void removedFromGroup( KopeteMetaContact *contact, KopeteGroup *group );
+	void removedFromGroup( Kopete::MetaContact *contact, Kopete::Group *group );
 
 	/**
 	 * @brief The contact was added to another group
 	 */
-	void addedToGroup( KopeteMetaContact *contact, KopeteGroup *to );
+	void addedToGroup( Kopete::MetaContact *contact, Kopete::Group *to );
 
 	/**
 	 * @brief a contact has been added into this metacontact
 	 *
 	 * This signal is emitted when a contact is added to this metacontact
 	 */
-	void contactAdded( KopeteContact *c );
+	void contactAdded( Kopete::Contact *c );
 
 	/**
 	 * @brief a contact has been removed from this metacontact
 	 *
 	 * This signal is emitted when a contact is removed from this metacontact
 	 */
-	void contactRemoved( KopeteContact *c );
-
-	/**
-	 * This metaContact is going to be saved to the contactlist. Plugins should
-	 * connect to this signal to update data with setPluginData()
-	 */
-	void aboutToSave( KopeteMetaContact *metaContact );
-
-	/**
-	 * One of the subcontacts' idle status has changed.  As with online status,
-	 * this can occur without the metacontact changing idle state
-	 */
-	void contactIdleStateChanged( KopeteContact *contact );
+	void contactRemoved( Kopete::Contact *c );
 
 	/**
 	 * Some part of this object's persistent data (as returned by toXML) has changed.
 	 */
-	void persistentDataChanged( KopeteMetaContact *metaContact );
+	void persistentDataChanged(  );
 
 private slots:
 	/**
@@ -431,49 +548,52 @@ private slots:
 	/**
 	 * One of the child contact's online status changed
 	 */
-	void slotContactStatusChanged( KopeteContact *c, const KopeteOnlineStatus &status, const KopeteOnlineStatus &oldStatus );
+	void slotContactStatusChanged( Kopete::Contact *c, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldStatus );
 
 	/**
 	 * One of the child contact's property changed
 	 */
-	void slotPropertyChanged( KopeteContact *contact, const QString &key, const QVariant &oldValue, const QVariant &newValue  );
+	void slotPropertyChanged( Kopete::Contact *contact, const QString &key, const QVariant &oldValue, const QVariant &newValue  );
 
 	/**
 	 * A child contact was deleted, remove it from the list, if it's still
 	 * there
 	 */
-	void slotContactDestroyed( KopeteContact* );
+	void slotContactDestroyed( Kopete::Contact* );
 
 	/**
 	 * If a plugin is loaded, maybe data about this plugin are already cached in the metacontact
 	 */
-	void slotPluginLoaded( KopetePlugin *plugin );
+	void slotPluginLoaded( Kopete::Plugin *plugin );
 
 	/**
-	 * Perform a delayed address book write
+	 * When all the plugins are loaded, set the Contact Source.
 	 */
-	void slotWriteAddressBook();
+	void slotAllPluginsLoaded();
 
-	/**
-	 * Emits the persistentDataChanged signal, passing this as the KopeteMetaContact* argument
-	 */
-	void emitPersistentDataChanged();
+protected:
+	//QImage photoFromContact( Kopete::Contact *c) const;
+	//QImage photoFromKABC( const QString &id ) const;
+	QImage photoFromCustom() const;
+	//QString nameFromContact( Kopete::Contact *c) const;
+	//QString nameFromKABC( const QString &id ) const;
+
+	QString sourceToString(PropertySource source) const;
+	PropertySource stringToSource(const QString &name) const;
 private:
-
-	KopeteMetaContactPrivate *d;
-
-	/**
-	 * Request an address book write, will be delayed to bundle any others happening around the same time
-	 */
-	void writeAddressBook();
-
-	static KABC::AddressBook* addressBook();
-    
-	static void splitField( const QString &str, QString &app, QString &name, QString &value );
-	
-	static KABC::AddressBook* m_addressBook;
+	class Private;
+	Private *d;
 };
 
+// util functions shared with metacontact property dialog
+KOPETE_EXPORT QImage photoFromContact( Kopete::Contact *c) /*const*/;
+KOPETE_EXPORT QImage photoFromKABC( const QString &id ) /*const*/;
+KOPETE_EXPORT QString nameFromContact( Kopete::Contact *c) /*const*/;
+KOPETE_EXPORT QString nameFromKABC( const QString &id ) /*const*/;
+
+} //END namespace Kopete
+
+
 #endif
 
 // vim: set noet ts=4 sts=4 sw=4:
