@@ -50,6 +50,7 @@ void KopetePrefs::load()
 
 	mIconTheme = config->readEntry("EmoticonTheme", defaultTheme());
 	mUseEmoticons = config->readBoolEntry("Use Emoticons", true);
+	mEmoticonsRequireSpaces = config->readBoolEntry("EmoticonsRequireSpaces" , true );
 	mShowOffline = config->readBoolEntry("ShowOfflineUsers", true);
 	mShowEmptyGroups = config->readBoolEntry("ShowEmptyGroups", true);
 	mGreyIdle = config->readBoolEntry("GreyIdleMetaContacts", true);
@@ -59,8 +60,15 @@ void KopetePrefs::load()
 	mUseQueue = config->readBoolEntry("Use Queue", true);
 	mRaiseMsgWindow = config->readBoolEntry("Raise Msg Window", false);
 	mShowEvents = config->readBoolEntry("Show Events in Chat Window", true);
-	mTrayflashNotify = config->readBoolEntry("Trayflash Notification", true);
+	mSpellCheck = config->readBoolEntry("SpellCheck", true);
+	mQueueUnreadMessages = config->readBoolEntry("Queue Unread Messages", false);
+	mQueueOnlyHighlightedMessagesInGroupChats = config->readBoolEntry("Queue Only Highlighted Messages In Group Chats", false);
+	mQueueOnlyMessagesOnAnotherDesktop = config->readBoolEntry("Queue Only Messages On Another Desktop", false);
 	mBalloonNotify = config->readBoolEntry("Balloon Notification", true);
+	mBalloonNotifyIgnoreClosesChatView = config->readBoolEntry("Balloon Notification Ignore Closes Chat View", false);
+	mTrayflashNotify = config->readBoolEntry("Trayflash Notification", true);
+	mTrayflashNotifyLeftClickOpensMessage = config->readBoolEntry("Trayflash Notification Left Click Opens Message", true);
+	mTrayflashNotifySetCurrentDesktopToChatView = config->readBoolEntry("Trayflash Notification Set Current Desktop To Chat View", false);
 	mSoundIfAway = config->readBoolEntry("Sound Notification If Away", true);
 	mChatWindowPolicy = config->readNumEntry("Chatwindow Policy", 0);
 	mTransparencyEnabled = config->readBoolEntry("ChatView Transparency Enabled", false);
@@ -124,7 +132,12 @@ void KopetePrefs::load()
 	int n = metaObject()->findProperty( "contactListDisplayMode" );
 	QString value = config->readEntry("DisplayMode",QString::fromLatin1("Default"));
 	mContactListDisplayMode = (ContactDisplayMode)metaObject()->property( n )->keyToValue( value.latin1() );
+	n = metaObject()->findProperty( "contactListIconMode" );
+	value = config->readEntry("IconMode",
+                                  QString::fromLatin1("IconDefault"));
+	mContactListIconMode = (IconDisplayMode) metaObject()->property( n )->keyToValue( value.latin1() );
 	mContactListIndentContacts = config->readBoolEntry("IndentContacts", false);
+	mContactListHideVerticalScrollBar = config->readBoolEntry("HideVerticalScrollBar", false );
 	mContactListUseCustomFonts = config->readBoolEntry("UseCustomFonts", false);
 	QFont font = KGlobalSettings::generalFont();
 	mContactListNormalFont = config->readFontEntry("NormalFont", &font);
@@ -137,7 +150,9 @@ void KopetePrefs::load()
 	mContactListAnimation = config->readBoolEntry("AnimateChanges", true);
 	mContactListFading = config->readBoolEntry("FadeItems", true);
 	mContactListFolding = config->readBoolEntry("FoldItems", true);
+	mContactListMouseNavigation = config->readBoolEntry("MouseNavigation", false );
 	mContactListAutoHide = config->readBoolEntry("AutoHide", false);
+	mContactListAutoHideVScroll = config->readBoolEntry("AutoHideVScroll", true );
 	mContactListAutoHideTimeout = config->readUnsignedNumEntry("AutoHideTimeout", 30);
 
 	// Load the reconnection setting
@@ -159,6 +174,7 @@ void KopetePrefs::save()
 
 	config->writeEntry("EmoticonTheme", mIconTheme);
 	config->writeEntry("Use Emoticons", mUseEmoticons);
+	config->writeEntry("EmoticonsRequireSpaces", mEmoticonsRequireSpaces);
 	config->writeEntry("ShowOfflineUsers", mShowOffline);
 	config->writeEntry("ShowEmptyGroups", mShowEmptyGroups);
 	config->writeEntry("GreyIdleMetaContacts", mGreyIdle);
@@ -168,8 +184,15 @@ void KopetePrefs::save()
 	config->writeEntry("Use Queue", mUseQueue);
 	config->writeEntry("Raise Msg Window", mRaiseMsgWindow);
 	config->writeEntry("Show Events in Chat Window", mShowEvents);
-	config->writeEntry("Trayflash Notification", mTrayflashNotify);
+	config->writeEntry("SpellCheck", mSpellCheck);
+	config->writeEntry("Queue Unread Messages", mQueueUnreadMessages);
+	config->writeEntry("Queue Only Highlighted Messages In Group Chats", mQueueOnlyHighlightedMessagesInGroupChats);
+	config->writeEntry("Queue Only Messages On Another Desktop", mQueueOnlyMessagesOnAnotherDesktop);
 	config->writeEntry("Balloon Notification", mBalloonNotify);
+	config->writeEntry("Balloon Notification Ignore Closes Chat View", mBalloonNotifyIgnoreClosesChatView);
+	config->writeEntry("Trayflash Notification", mTrayflashNotify);
+	config->writeEntry("Trayflash Notification Left Click Opens Message", mTrayflashNotifyLeftClickOpensMessage);
+	config->writeEntry("Trayflash Notification Set Current Desktop To Chat View", mTrayflashNotifySetCurrentDesktopToChatView);
 	config->writeEntry("Sound Notification If Away", mSoundIfAway);
 	config->writeEntry("Chatwindow Policy", mChatWindowPolicy);
 	config->writeEntry("ChatView Transparency Enabled", mTransparencyEnabled);
@@ -203,7 +226,10 @@ void KopetePrefs::save()
 	config->setGroup("ContactList");
 	int n = metaObject()->findProperty( "contactListDisplayMode" );
 	config->writeEntry("DisplayMode", metaObject()->property( n )->valueToKey( mContactListDisplayMode ));
+	n = metaObject()->findProperty( "contactListIconMode" );
+	config->writeEntry("IconMode", metaObject()->property( n )->valueToKey( mContactListIconMode ));
 	config->writeEntry("IndentContacts", mContactListIndentContacts);
+	config->writeEntry("HideVerticalScrollBar", mContactListHideVerticalScrollBar );
 	config->writeEntry("UseCustomFonts", mContactListUseCustomFonts);
 	config->writeEntry("NormalFont", mContactListNormalFont);
 	config->writeEntry("SmallFont", mContactListSmallFont);
@@ -211,7 +237,9 @@ void KopetePrefs::save()
 	config->writeEntry("AnimateChanges", mContactListAnimation);
 	config->writeEntry("FadeItems", mContactListFading);
 	config->writeEntry("FoldItems", mContactListFolding);
+	config->writeEntry("MouseNavigation", mContactListMouseNavigation );
 	config->writeEntry("AutoHide", mContactListAutoHide);
+	config->writeEntry("AutoHideVScroll", mContactListAutoHideVScroll );
 	config->writeEntry("AutoHideTimeout", mContactListAutoHideTimeout);
 
 	//Save the reconnection setting
@@ -244,13 +272,21 @@ void KopetePrefs::save()
 
 void KopetePrefs::setIconTheme(const QString &value)
 {
-	if( mIconTheme != value ) mMessageAppearanceChanged = true;
+	if( mIconTheme != value )
+	{
+		mMessageAppearanceChanged = true;
+		mContactListAppearanceChanged = true;
+	}
 	mIconTheme = value;
 }
 
 void KopetePrefs::setUseEmoticons(bool value)
 {
-	if( mUseEmoticons != value ) mMessageAppearanceChanged = true;
+	if( mUseEmoticons != value )
+	{
+		 mMessageAppearanceChanged = true;
+		 mContactListAppearanceChanged = true;
+	}
 	mUseEmoticons = value;
 }
 
@@ -315,11 +351,46 @@ void KopetePrefs::setTrayflashNotify(bool value)
 	mTrayflashNotify = value;
 }
 
+void KopetePrefs::setSpellCheck(bool value)
+{
+	mSpellCheck = value;
+}
+
+void KopetePrefs::setQueueUnreadMessages(bool value)
+{
+	mQueueUnreadMessages = value;
+}
+
+void KopetePrefs::setQueueOnlyHighlightedMessagesInGroupChats(bool value)
+{
+	mQueueOnlyHighlightedMessagesInGroupChats = value;
+}
+
+void KopetePrefs::setQueueOnlyMessagesOnAnotherDesktop(bool value)
+{
+	mQueueOnlyMessagesOnAnotherDesktop = value;
+}
+
+void KopetePrefs::setTrayflashNotifyLeftClickOpensMessage(bool value)
+{
+	mTrayflashNotifyLeftClickOpensMessage = value;
+}
+
+void KopetePrefs::setTrayflashNotifySetCurrentDesktopToChatView(bool value)
+{
+	mTrayflashNotifySetCurrentDesktopToChatView = value;
+}
+
 void KopetePrefs::setBalloonNotify(bool value)
 {
 	mBalloonNotify = value;
 }
 
+void KopetePrefs::setBalloonNotifyIgnoreClosesChatView(bool value)
+{
+	mBalloonNotifyIgnoreClosesChatView = value;
+}
+
 void KopetePrefs::setSoundIfAway(bool value)
 {
 	mSoundIfAway = value;
@@ -346,9 +417,15 @@ void KopetePrefs::_setStyleSheet(const QString &value)
 	{
 		mStyleSheet = value;
 	}
-
+	
 	styleFileName = locate( "appdata", QString::fromLatin1("styles/") + mStyleSheet + QString::fromLatin1(".xsl"));
+
+	/* We must find the path of style data to replace $appdata by correct value in xsl that Kopete XSLT doesn't processing well (and impossible to fix without changing lots of things).  */
+	mStyleDataPath = styleFileName;
+	mStyleDataPath.replace(mStyleSheet + QString::fromLatin1(".xsl"),QString::fromLatin1("data/"));
+
 	mStyleContents = fileContents(styleFileName);
+
 }
 
 void KopetePrefs::setFontFace( const QFont &value )
@@ -495,12 +572,24 @@ void KopetePrefs::setContactListIndentContacts( bool v )
 	mContactListIndentContacts = v;
 }
 
+void KopetePrefs::setContactListHideVerticalScrollBar( bool v )
+{
+	if( v != mContactListHideVerticalScrollBar ) mContactListAppearanceChanged = true;
+	mContactListHideVerticalScrollBar = v;
+}
+
 void KopetePrefs::setContactListDisplayMode( ContactDisplayMode v )
 {
 	if( v != mContactListDisplayMode ) mContactListAppearanceChanged = true;
 	mContactListDisplayMode = v;
 }
 
+void KopetePrefs::setContactListIconMode( IconDisplayMode v )
+{
+	if( v != mContactListIconMode ) mContactListAppearanceChanged = true;
+	mContactListIconMode = v;
+}
+
 void KopetePrefs::setContactListUseCustomFonts( bool v )
 {
 	if( v != mContactListUseCustomFonts ) mContactListAppearanceChanged = true;
@@ -555,12 +644,24 @@ void KopetePrefs::setContactListFolding( bool n )
 	mContactListFolding = n;
 }
 
+void KopetePrefs::setContactListMouseNavigation( bool n )
+{
+	if( n != mContactListMouseNavigation ) mContactListAppearanceChanged = true;
+	mContactListMouseNavigation = n;
+}
+
 void KopetePrefs::setContactListAutoHide( bool n )
 {
 	if( n != mContactListAutoHide ) mContactListAppearanceChanged = true;
 	mContactListAutoHide = n;
 }
 
+void KopetePrefs::setContactListAutoHideVScroll( bool n )
+{
+	if( n != mContactListAutoHideVScroll ) mContactListAppearanceChanged = true;
+	mContactListAutoHideVScroll = n;
+}
+
 void KopetePrefs::setContactListAutoHideTimeout( unsigned int n )
 {
 	if( n != mContactListAutoHideTimeout ) mContactListAppearanceChanged = true;
@@ -572,11 +673,20 @@ void KopetePrefs::setReconnectOnDisconnect( bool newSetting )
 	mReconnectOnDisconnect = newSetting;
 }
 
-
 void KopetePrefs::setAutoConnect(bool b)
 {
 	mAutoConnect=b;
 }
 
+void KopetePrefs::setEmoticonsRequireSpaces( bool b )
+{
+	if( mEmoticonsRequireSpaces != b )
+	{
+		 mMessageAppearanceChanged = true;
+		 mContactListAppearanceChanged = true;
+	}
+	mEmoticonsRequireSpaces=b;
+}
+
 #include "kopeteprefs.moc"
 // vim: set noet ts=4 sts=4 sw=4:
