@@ -325,18 +325,26 @@ void AliasPreferences::slotAddAlias()
 		else
 		{
 			QString command = addDialog.command->text();
+			ProtocolList protocols = selectedProtocols( &addDialog );
 
-			if( !Kopete::CommandHandler::commandHandler()->commandHandled( alias ) )
+			// Loop through selected protocols
+
+			for( ProtocolList::Iterator it = protocols.begin(); it != protocols.end(); ++it )
 			{
-				addAlias( alias, command, selectedProtocols( &addDialog) );
-				emit KCModule::changed(true);
-			}
-			else
-			{
-				KMessageBox::error( this, i18n("<qt>Could not add alias <b>%1</b>. This "
-					"command is already being handled by either another alias or "
-					"Kopete itself.</qt>").arg(alias),i18n("Could Not Add Alias") );
+
+				// And check if they already have the command enabled
+
+				if( Kopete::CommandHandler::commandHandler()->commandHandledByProtocol( alias, *it ) )
+				{
+					KMessageBox::error( this, i18n("<qt>Could not add alias <b>%1</b>. This "
+						"command is already being handled by either another alias or "
+						"Kopete itself.</qt>").arg(alias), i18n("Could Not Add Alias") );
+					return;
+				}
 			}
+			addAlias( alias, command, protocols );
+			emit KCModule::changed(true); 
+
 		}
 	}
 }
@@ -350,12 +358,14 @@ const ProtocolList AliasPreferences::selectedProtocols( EditAliasDialog *dialog
 	{
 		if( item->isSelected() )
 		{
-			// If you don't have the selected protocol enabled, Kopete::PluginManager::self()->plugin()
+
+			// If you dont have the selected protocol enabled, Kopete::PluginManager::self()->plugin
 			// will return NULL, check for that
 
 			if(Kopete::PluginManager::self()->plugin( static_cast<ProtocolItem*>(item)->id) )
 				protocolList.append( (Kopete::Protocol*)
-					Kopete::PluginManager::self()->plugin( static_cast<ProtocolItem*>(item)->id ) );
+					Kopete::PluginManager::self()->plugin( static_cast<ProtocolItem*>(item)->id )
+			);
 		}
 		item = item->nextSibling();
 	}
@@ -405,26 +415,35 @@ void AliasPreferences::slotEditAlias()
 			{
 				QString command = editDialog.command->text();
 
-				if( alias == oldAlias ||
-					!Kopete::CommandHandler::commandHandler()->commandHandled( alias ) )
+				if( alias == oldAlias )
 				{
-					for( ProtocolList::Iterator it = protocols.begin(); it != protocols.end(); ++it )
+                                        for( ProtocolList::Iterator it = protocols.begin(); it != protocols.end(); ++it )
+                                        {
+                                                Kopete::CommandHandler::commandHandler()->unregisterAlias(
+                                                        *it,
+                                                        oldAlias
+                                                );
+                                        }
+
+
+                                        ProtocolList selProtocols = selectedProtocols( &editDialog );
+
+					for( ProtocolList::Iterator it = selProtocols.begin(); it != selProtocols.end(); ++it )
 					{
-						Kopete::CommandHandler::commandHandler()->unregisterAlias(
-							*it,
-							oldAlias
-						);
+						if( Kopete::CommandHandler::commandHandler()->commandHandledByProtocol( alias, *it ) )
+						{
+							KMessageBox::error( this, i18n("<qt>Could not add alias <b>%1</b>. This "
+							"command is already being handled by either another alias or "
+							"Kopete itself.</qt>").arg(alias), i18n("Could Not Add Alias") );
+						return;
+						}
 					}
 
 					delete item;
 
-					addAlias( alias, command, selectedProtocols( &editDialog ) );
+					addAlias( alias, command, selProtocols );
 					emit KCModule::changed(true);
 				}
-				else
-				{
-					KMessageBox::error( this, i18n("<qt>Could not add alias <b>%1</b>. This command is already being handled by either another alias or Kopete itself.</qt>").arg(alias),i18n("Could Not Add Alias") );
-				}
 			}
 		}
 	}
