@@ -60,6 +60,8 @@ void ConnectionStatusPlugin::slotCheckStatus()
 
 		return;
 	}
+
+	m_buffer = QString::null;
 	
 	// Use KProcess to run netstat -rn. We'll then parse the output of
 	// netstat -rn in slotProcessStdout() to see if it mentions the
@@ -83,6 +85,8 @@ void ConnectionStatusPlugin::slotProcessExited( KProcess *process )
 {
 	if ( process == m_process )
 	{
+		setConnectedStatus( m_buffer.contains( "default" ) );
+		m_buffer = QString::null;
 		delete m_process;
 		m_process = 0L;
 	}
@@ -92,9 +96,8 @@ void ConnectionStatusPlugin::slotProcessStdout( KProcess *, char *buffer, int bu
 {
 	// Look for a default gateway
 	//kdDebug( 14301 ) << k_funcinfo << endl;
-	QString qsBuffer = QString::fromLatin1( buffer, buflen );
+	m_buffer += QString::fromLatin1( buffer, buflen );
 	//kdDebug( 14301 ) << qsBuffer << endl;
-	setConnectedStatus( qsBuffer.contains( "default" ) );
 }
 
 void ConnectionStatusPlugin::setConnectedStatus( bool connected )
