@@ -3,7 +3,7 @@
                              -------------------
     begin                : dim nov 17 2002
     copyright            : (C) 2002 by Olivier Goffart
-    email                : ogoffart@tiscalinet.be
+    email                : ogoffart @ kde.org
  ***************************************************************************/
 
 /***************************************************************************
