@@ -467,8 +467,6 @@ void HistoryDialog::searchFirstStep()
 
 	if (!mSearch)
 	{
-		delete mSearch;
-		mSearch = 0L;
 		return;
 	}
 	
@@ -490,7 +488,7 @@ void HistoryDialog::searchFirstStep()
 
 				QFile file(mLogger->getFileName(*it, mSearch->item->date()));
 				file.open(IO_ReadOnly);
-				if (!&file)
+				if (!file.isOpen())
 				{
 					continue;
 				}
@@ -529,7 +527,7 @@ void HistoryDialog::searchFirstStep()
 			if (mSearch->dateSearchMap[mSearch->item->date()].contains(mSearch->item->metaContact()))
 				mSearch->item->setVisible(true);
 		}
-		while(mSearch->item = static_cast<KListViewDateItem *>(mSearch->item->nextSibling()));
+		while((mSearch->item = static_cast<KListViewDateItem *>(mSearch->item->nextSibling())));
 		mMainWidget->searchButton->setText(i18n("&Search"));
 
 		delete mSearch;
