@@ -65,7 +65,7 @@ public:
 	GaduDCC*	gaduDcc_;
 
 	QTimer*		pingTimer_;
-
+	
 	QTextCodec*	textcodec_;
 	KFileDialog*	saveListDialog;
 	KFileDialog*	loadListDialog;
@@ -83,24 +83,34 @@ public:
 
 	QString		lastDescription;
 	bool		forFriends;
-
-	KConfigGroup*	config;
+        
+	QTimer*         exportTimer_;
+	bool		exportUserlist;
+	
+	KConfigGroup*			config;
 	Kopete::OnlineStatus		status;
 	QValueList<unsigned int>	servers;
 	KGaduLoginParams		loginInfo;
 };
 
-// FIXME: use dynamic cache please, i consider this as broken resolution of this problem
+// 10s is enough ;p
+#define USERLISTEXPORT_TIMEOUT (10*1000)
 
-static const int NUM_SERVERS = 5;
-static const char* const servers_ip[ NUM_SERVERS ] = {
+// FIXME: use dynamic cache please, i consider this as broken resolution of this problem
+static const char* const servers_ip[] = {
 	"217.17.41.88",
+	"217.17.41.92",
+	"217.17.41.93",
  	"217.17.41.85",
 	"217.17.41.87",
 	"217.17.41.86",
 	"217.17.41.84",
+	"217.17.41.83",
+	"217.17.41.82"
 };
 
+#define NUM_SERVERS (sizeof(servers_ip)/sizeof(char*))
+
  GaduAccount::GaduAccount( Kopete::Protocol* parent, const QString& accountID,const char* name )
 : Kopete::PasswordedAccount( parent, accountID, 0, name )
 {
@@ -117,12 +127,12 @@ static const char* const servers_ip[ NUM_SERVERS ] = {
 
 	KGlobal::config()->setGroup( "Gadu" );
 
-	setMyself( new GaduContact(  accountId().toInt(), accountId(), this, new Kopete::MetaContact() ) );
+	setMyself( new GaduContact( accountId().toInt(), accountId(), this, Kopete::ContactList::self()->myself() ) );
 
 	p->status = GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL );
 	p->lastDescription = QString::null;
 
-	for ( int i = 0; i < NUM_SERVERS; i++ ) {
+	for ( unsigned int i = 0; i < NUM_SERVERS ; i++ ) {
 		ip.setAddress( QString( servers_ip[i] ) );
 		p->servers.append( htonl( ip.toIPv4Address() ) );
 		kdDebug( 14100 ) << "adding IP: " <<  p->servers[ i ] << " to cache" << endl;
@@ -140,13 +150,15 @@ static const char* const servers_ip[ NUM_SERVERS ] = {
 	p->loginInfo.client_addr	= 0;
 
 	p->pingTimer_ = new QTimer( this );
+	p->exportTimer_ = new QTimer( this );
 
+	p->exportUserlist = false;
 	p->gaduDcc_ = NULL;
 
 	p->config = configGroup();
 
-	initActions();
 	initConnections();
+	initActions();
 
 	QString nick = p->config->readEntry( QString::fromAscii( "nickName" ) );
 	if ( !nick.isNull() ) {
@@ -186,8 +198,6 @@ GaduAccount::initConnections()
 				SLOT( error( const QString&, const QString& ) ) );
 	QObject::connect( p->session_, SIGNAL( messageReceived( KGaduMessage* ) ),
 				SLOT( messageReceived( KGaduMessage* ) )  );
-	QObject::connect( p->session_, SIGNAL( notify( KGaduNotifyList* ) ),
-				SLOT( notify( KGaduNotifyList* ) ) );
 	QObject::connect( p->session_, SIGNAL( contactStatusChanged( KGaduNotify* ) ),
 				SLOT( contactStatusChanged( KGaduNotify* ) ) );
 	QObject::connect( p->session_, SIGNAL( connectionFailed( gg_failure_t )),
@@ -198,8 +208,8 @@ GaduAccount::initConnections()
 				SLOT( slotSessionDisconnect( Kopete::Account::DisconnectReason ) ) );
 	QObject::connect( p->session_, SIGNAL( ackReceived( unsigned int ) ),
 				SLOT( ackReceived( unsigned int ) ) );
-	QObject::connect( p->session_, SIGNAL( pubDirSearchResult( const SearchResult& ) ),
-				SLOT( slotSearchResult( const SearchResult& ) ) );
+	QObject::connect( p->session_, SIGNAL( pubDirSearchResult( const SearchResult&, unsigned int  ) ),
+				SLOT( slotSearchResult( const SearchResult&, unsigned int ) ) );
 	QObject::connect( p->session_, SIGNAL( userListExported() ),
 				SLOT( userListExportDone() ) );
 	QObject::connect( p->session_, SIGNAL( userListRecieved( const QString& ) ),
@@ -209,6 +219,9 @@ GaduAccount::initConnections()
 
 	QObject::connect( p->pingTimer_, SIGNAL( timeout() ),
 				SLOT( pingServer() ) );
+
+	QObject::connect( p->exportTimer_, SIGNAL( timeout() ),
+				SLOT( slotUserlistSynch() ) );
 }
 
 void
@@ -336,6 +349,24 @@ GaduAccount::setOnlineStatus( const Kopete::OnlineStatus& status , const QString
 	changeStatus( status, reason);
 }
 
+void
+GaduAccount::slotUserlistSynch()
+{
+	if ( !p->exportUserlist ) {
+		return;
+	}
+	p->exportUserlist = false;
+	kdDebug(14100) << "userlist changed, exporting" << endl;
+	slotExportContactsList();
+}
+
+void
+GaduAccount::userlistChanged()
+{
+	p->exportUserlist = true;
+	p->exportTimer_->changeInterval( USERLISTEXPORT_TIMEOUT );
+}
+
 bool
 GaduAccount::createContact( const QString& contactId, Kopete::MetaContact* parentContact )
 {
@@ -346,15 +377,21 @@ GaduAccount::createContact( const QString& contactId, Kopete::MetaContact* paren
 	newContact->setParentIdentity( accountId() );
 	addNotify( uinNumber );
 
+	userlistChanged();
+	
 	return true;
 }
 
 void
 GaduAccount::changeStatus( const Kopete::OnlineStatus& status, const QString& descr )
 {
+	unsigned int ns;
+	
+	kdDebug(14100) << "##### change status #####" << endl;
 	kdDebug(14100) << "### Status = " << p->session_->isConnected() << endl;
 	kdDebug(14100) << "### Status description = \"" << descr << "\"" << endl;
 
+	// if change to not available, log off
 	if ( GG_S_NA( status.internalStatus() ) ) {
 		if ( !p->session_->isConnected() ) {
 			return;//already logged off
@@ -370,6 +407,21 @@ GaduAccount::changeStatus( const Kopete::OnlineStatus& status, const QString& de
 		dccOff();
 	}
 	else {
+		// if status is for no desc, but we get some desc, than convert it to status with desc
+		if (!descr.isEmpty() && !GaduProtocol::protocol()->statusWithDescription( status.internalStatus() ) ) {
+			// and rerun us again. This won't cause any recursive call, as both conversions are static
+			ns = GaduProtocol::protocol()->statusToWithDescription( status );
+			changeStatus( GaduProtocol::protocol()->convertStatus( ns ), descr );
+			return;
+		}
+
+		// well, if it's empty but we want to set status with desc, change it too
+                if (descr.isEmpty() && GaduProtocol::protocol()->statusWithDescription( status.internalStatus() ) ) {
+			ns = GaduProtocol::protocol()->statusToWithoutDescription( status );
+			changeStatus( GaduProtocol::protocol()->convertStatus( ns ), descr );
+			return;
+		}
+				
 		if ( !p->session_->isConnected() ) {
 			if ( password().cachedValue().isEmpty() ) {
 				// FIXME: when status string added to connect(), use it here
@@ -493,6 +545,7 @@ GaduAccount::removeContact( const GaduContact* c )
 	if ( isConnected() ) {
 		const uin_t u = c->uin();
 		p->session_->removeNotify( u );
+		userlistChanged();
 	}
 }
 
@@ -572,20 +625,6 @@ GaduAccount::ackReceived( unsigned int recipient  )
 	}
 }
 
-
-void
-GaduAccount::notify( KGaduNotifyList* notifyList )
-{
-	QPtrListIterator<KGaduNotify>notifyListIterator( *notifyList );
-	unsigned int i;
-
-	for ( i = notifyList->count() ; i-- ; ++notifyListIterator ) {
-		kdDebug(14100) << "### NOTIFY " << (*notifyListIterator)->contact_id << " " << (*notifyListIterator)->status << endl;
-		contactStatusChanged( (*notifyListIterator) );
-	}
-}
-
-
 void
 GaduAccount::contactStatusChanged( KGaduNotify* gaduNotify )
 {
@@ -643,7 +682,7 @@ GaduAccount::connectionFailed( gg_failure_t failure )
 				}
 			}
 			else {
-				if ( p->currentServer == NUM_SERVERS-1 ) {
+				if ( p->currentServer == NUM_SERVERS - 1 ) {
 					p->serverIP = 0;
 					p->currentServer = -1;
 					kdDebug(14100) << "trying : " << "IP from hub " << endl;
@@ -695,25 +734,25 @@ GaduAccount::dccOff()
 }
 
 void
-GaduAccount::slotIncomingDcc( unsigned int UIN )
+GaduAccount::slotIncomingDcc( unsigned int uin )
 {
 	GaduContact* contact;
 	GaduDCCTransaction* trans;
 
-	if ( !UIN ) {
+	if ( !uin ) {
 		return;
 	}
 
-	contact = static_cast<GaduContact*>( contacts()[ QString::number( UIN ) ] );
+	contact = static_cast<GaduContact*>( contacts()[ QString::number( uin ) ] );
 
 	if ( !contact ) {
-	  kdDebug(14100) << "attempt to make dcc connection from unknown uin " << UIN << endl;
+	  kdDebug(14100) << "attempt to make dcc connection from unknown uin " << uin << endl;
 		return;
 	}
 
 	// if incapabile to transfer files, forget about it.
 	if ( contact->contactPort() < 10 ) {
-	  kdDebug(14100) << "can't respond to " << UIN << " request, his listeing port is too low" << endl;
+	  kdDebug(14100) << "can't respond to " << uin << " request, his listeing port is too low" << endl;
 	  return;
 	}
 
@@ -734,7 +773,11 @@ GaduAccount::connectionSucceed( )
 	startNotify();
 
 	p->session_->requestContacts();
-	p->pingTimer_->start( 180000 );//3 minute timeout
+	p->pingTimer_->start( 3*60*1000 );//3 minute timeout
+	pingServer();
+
+	// check if we need to export userlist every USERLISTEXPORT_TIMEOUT ms
+	p->exportTimer_->start( USERLISTEXPORT_TIMEOUT );
 }
 
 void
@@ -790,6 +833,9 @@ GaduAccount::userlist( const QString& contactsListString )
 	Kopete::MetaContact* metaContact;
 	unsigned int i;
 
+	// don't export any new changes that were just imported :-)
+	p->exportTimer_->stop();
+	
 	for ( i = 0; i != contactsList.size() ; i++ ) {
 		kdDebug(14100) << "uin " << contactsList[i].uin << endl;
 
@@ -830,6 +876,9 @@ GaduAccount::userlist( const QString& contactsListString )
 			}
 		}
 	}
+	// start to check if we need to export userlist 
+	p->exportUserlist = false;	
+	p->exportTimer_->start( USERLISTEXPORT_TIMEOUT );
 }
 
 void
@@ -868,7 +917,6 @@ GaduAccount::slotExportContactsListToFile()
 	    myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString() ) );
 
 	if ( p->saveListDialog->exec() == QDialog::Accepted ) {
-
 		QCString list = p->textcodec_->fromUnicode( userlist()->asString() );
 
 		if ( tempFile.status() ) {
@@ -899,6 +947,9 @@ GaduAccount::slotExportContactsListToFile()
 void
 GaduAccount::slotImportContactsFromFile()
 {
+	KURL url;
+	QCString list;
+	QString oname;
 
 	if ( p->loadListDialog ) {
 		kdDebug( 14100 ) << "load contacts from file: alread waiting for input " << endl ;
@@ -912,17 +963,9 @@ GaduAccount::slotImportContactsFromFile()
 	    myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString() ) );
 
 	if ( p->loadListDialog->exec() == QDialog::Accepted ) {
-
-		QCString list;
-
-		KURL url = p->loadListDialog->selectedURL();
-		QString oname;
-		kdDebug(14100) << "a:"<<url<<"\nb:" << oname << endl;
-		if ( KIO::NetAccess::download(	url,
-						oname,
-						Kopete::UI::Global::mainWidget()
-						) ) {
-
+		url = p->loadListDialog->selectedURL();
+		kdDebug(14100) << "a:" << url << "\nb:" << oname << endl;
+		if ( KIO::NetAccess::download( url, oname, Kopete::UI::Global::mainWidget() ) ) {
 			QFile tempFile( oname );
 			if ( tempFile.open( IO_ReadOnly ) ) {
 				list = tempFile.readAll();
@@ -950,13 +993,24 @@ GaduAccount::slotImportContactsFromFile()
 	p->loadListDialog = NULL;
 }
 
+unsigned int
+GaduAccount::getPersonalInformation()
+{
+	return p->session_->getPersonalInformation();
+}
+
+bool 
+GaduAccount::publishPersonalInformation( ResLine& d )
+{
+	return p->session_->publishPersonalInformation( d );
+}
+
 void
 GaduAccount::slotExportContactsList()
 {
 	p->session_->exportContactsOnServer( userlist() );
 }
 
-
 GaduContactsList*
 GaduAccount::userlist()
 {
@@ -1017,13 +1071,10 @@ GaduAccount::slotDescription()
 	delete away;
 }
 
-bool
-GaduAccount::pubDirSearch( QString& name, QString& surname, QString& nick,
-			    int UIN, QString& city, int gender,
-			    int ageFrom, int ageTo, bool onlyAlive )
+unsigned int
+GaduAccount::pubDirSearch( ResLine& query, int ageFrom, int ageTo, bool onlyAlive )
 {
-	return p->session_->pubDirSearch( name, surname, nick, UIN, city, gender,
-							ageFrom, ageTo, onlyAlive );
+	return p->session_->pubDirSearch( query, ageFrom, ageTo, onlyAlive );
 }
 
 void
@@ -1033,16 +1084,16 @@ GaduAccount::pubDirSearchClose()
 }
 
 void
-GaduAccount::slotSearchResult( const SearchResult& result )
+GaduAccount::slotSearchResult( const SearchResult& result, unsigned int seq )
 {
-	emit pubDirSearchResult( result );
+	emit pubDirSearchResult( result, seq );
 }
 
 void
-GaduAccount::sendFile( GaduContact* peer )
+GaduAccount::sendFile( GaduContact* peer, QString& filePath )
 {
 	GaduDCCTransaction* gtran = new GaduDCCTransaction( p->gaduDcc_ );
-	gtran->setupOutgoing( peer );
+	gtran->setupOutgoing( peer, filePath );
 }
 
 void
