@@ -22,6 +22,7 @@
 #include "gadueditaccount.h"
 #include "gaduaccount.h"
 #include "gaduprotocol.h"
+#include "gadusession.h"
 
 #include <qradiobutton.h>
 #include <qcombobox.h>
@@ -32,6 +33,7 @@
 #include <qbutton.h>
 #include <qregexp.h>
 #include <qpushbutton.h>
+#include <qgroupbox.h>
 
 #include <klineedit.h>
 #include <kmessagebox.h>
@@ -56,32 +58,120 @@ GaduEditAccount::GaduEditAccount( GaduProtocol* proto, Kopete::Account* ident, Q
 	if ( account() == NULL ) {
 		useTls_->setCurrentItem( GaduAccount::TLS_no );
 		registerNew->setEnabled( true );
+		account_ = NULL;
 	}
 	else {
+		account_ = static_cast<GaduAccount*>(ident);
+
 		registerNew->setDisabled( true );
 		loginEdit_->setDisabled( true );
-		loginEdit_->setText( account()->accountId() );
+		loginEdit_->setText( account_->accountId() );
 
-		passwordWidget_->load( &static_cast<GaduAccount*>(account())->password() );
-		
-		QString nick = account()->myself()->property( 
-				Kopete::Global::Properties::self()->nickName() ).value().toString();	
+		passwordWidget_->load( &account_->password() );
+
+		QString nick = account()->myself()->property(
+				Kopete::Global::Properties::self()->nickName() ).value().toString();
 		if ( nick.isEmpty() ) {
-			nick = account()->myself()->contactId();
+			nick = account_->myself()->contactId();
 		}
-		
+
 		nickName->setText( nick );
 
-		autoLoginCheck_->setChecked( account()->excludeConnect() );
-		dccCheck_->setChecked( static_cast<GaduAccount*>(account())->dccEnabled() );
-		useTls_->setCurrentItem( isSsl ?  ( static_cast<GaduAccount*> (account()) ->useTls() ) : 2 );
+		autoLoginCheck_->setChecked( account_->excludeConnect() );
+		dccCheck_->setChecked( account_->dccEnabled() );
+		useTls_->setCurrentItem( isSsl ? ( account_->useTls() ) : 2 );
+
+		connect( account(), SIGNAL( pubDirSearchResult( const SearchResult&, unsigned int ) ),
+					SLOT( slotSearchResult( const SearchResult&, unsigned int ) ) );
+		connectLabel->setText( i18n( "personal information being fetched from server",
+					"<p align=\"center\">Fetching from server</p>" ) );
+		seqNr = account_->getPersonalInformation();
 	}
 
-	QObject::connect( registerNew, SIGNAL( clicked( ) ), SLOT( registerNewAccount( ) ) );
+	connect( registerNew, SIGNAL( clicked( ) ), SLOT( registerNewAccount( ) ) );
+
 	QWidget::setTabOrder( loginEdit_, passwordWidget_->mRemembered );
 	QWidget::setTabOrder( passwordWidget_->mRemembered, passwordWidget_->mPassword );
 	QWidget::setTabOrder( passwordWidget_->mPassword, autoLoginCheck_ );
+}
 
+void
+GaduEditAccount::publishUserInfo()
+{
+	ResLine sr;
+
+	enableUserInfo( false );
+	
+	sr.firstname	= uiName->text();
+	sr.surname	= uiSurname->text();
+	sr.nickname	= nickName->text();
+	sr.age		= uiYOB->text();
+	sr.city		= uiCity->text();
+	sr.meiden	= uiMeiden->text();
+	sr.orgin	= uiOrgin->text();
+
+	kdDebug(14100) << uiGender->currentItem() << " gender " << endl;
+	if ( uiGender->currentItem() == 1 ) {
+		kdDebug(14100) << "so you become female now" << endl;
+		sr.gender = QString( GG_PUBDIR50_GENDER_SET_FEMALE );
+	}
+	if ( uiGender->currentItem() == 2 ) {
+		kdDebug(14100) << "so you become male now" << endl;
+		sr.gender = QString( GG_PUBDIR50_GENDER_SET_MALE );
+	}
+
+	if ( account_ ) {
+		account_->publishPersonalInformation( sr );
+	}
+}
+
+void
+GaduEditAccount::slotSearchResult( const SearchResult& result, unsigned int seq )
+{
+	if ( !( seq != 0 && seqNr != 0 && seq == seqNr ) ) {
+		return;
+	}
+        
+	connectLabel->setText( " " );
+		
+	uiName->setText( result[0].firstname );
+	uiSurname->setText( result[0].surname );
+	nickName->setText( result[0].nickname );
+	uiYOB->setText( result[0].age );
+	uiCity->setText( result[0].city );
+
+	kdDebug( 14100 ) << "gender found: " << result[0].gender << endl;
+	if ( result[0].gender == QString( GG_PUBDIR50_GENDER_SET_FEMALE ) ) {
+		uiGender->setCurrentItem( 1 );
+		kdDebug(14100) << "looks like female" << endl;
+	}
+	else {
+		if ( result[0].gender == QString( GG_PUBDIR50_GENDER_SET_MALE ) ) {
+			uiGender->setCurrentItem( 2 );
+			kdDebug( 14100 ) <<" looks like male" << endl;
+		}
+	}
+
+	uiMeiden->setText( result[0].meiden );
+	uiOrgin->setText( result[0].orgin );
+
+	enableUserInfo( true );
+	
+	disconnect( SLOT( slotSearchResult( const SearchResult&, unsigned int ) ) );
+}
+
+void
+GaduEditAccount::enableUserInfo( bool e )
+{
+	uiName->setEnabled( e );
+	uiSurname->setEnabled( e );
+	uiYOB->setEnabled( e );
+	uiCity->setEnabled( e );
+	uiGender->setEnabled( e );
+	uiMeiden->setEnabled( e );
+	uiOrgin->setEnabled( e );
+	
+//	connectLabel->setEnabled( !e );
 }
 
 void
@@ -141,23 +231,26 @@ GaduEditAccount::validateData()
 Kopete::Account*
 GaduEditAccount::apply()
 {
+	publishUserInfo();
+	
 	if ( account() == NULL ) {
 		setAccount( new GaduAccount( protocol_, loginEdit_->text() ) );
+		account_ = static_cast<GaduAccount*>( account() );
 	}
 
-	account()->setExcludeConnect( autoLoginCheck_->isChecked() );
+	account_->setExcludeConnect( autoLoginCheck_->isChecked() );
 
-	passwordWidget_->save( &static_cast<GaduAccount*>(account())->password() );
+	passwordWidget_->save( &account_->password() );
+
+	account_->myself()->setProperty( Kopete::Global::Properties::self()->nickName(), nickName->text() );
 
-	account()->myself()->setProperty( Kopete::Global::Properties::self()->nickName(), nickName->text() );
-	
 	// this is changed only here, so i won't add any proper handling now
-        account()->configGroup()->writeEntry( QString::fromAscii( "nickName" ), nickName->text() );
-		
-	account()->setExcludeConnect( autoLoginCheck_->isChecked() );
-	( static_cast<GaduAccount*> (account()) )->setUseTls( (GaduAccount::tlsConnection) useTls_->currentItem() );
+        account_->configGroup()->writeEntry( QString::fromAscii( "nickName" ), nickName->text() );
 
-	if ( static_cast<GaduAccount*>(account())->setDcc( dccCheck_->isChecked() ) == false ) {
+	account_->setExcludeConnect( autoLoginCheck_->isChecked() );
+	account_->setUseTls( (GaduAccount::tlsConnection) useTls_->currentItem() );
+
+	if ( account_->setDcc( dccCheck_->isChecked() ) == false ) {
 		KMessageBox::sorry( this, i18n( "<b>Starting DCC listening socket failed; dcc is not working now.</b>" ), i18n( "Gadu-Gadu" ) );
 	}
 
