@@ -34,15 +34,15 @@
 #include <kdebug.h>
 #include <qdom.h>
 
-#include "kopetemessagemanager.h"
+#include "kopetechatsession.h"
 #include "kcodecaction.h"
 #include "ircguiclient.h"
 #include "ircaccount.h"
 #include "irccontact.h"
 
-IRCGUIClient::IRCGUIClient( KopeteMessageManager *parent ) : QObject(parent) , KXMLGUIClient(parent)
+IRCGUIClient::IRCGUIClient( Kopete::ChatSession *parent ) : QObject(parent) , KXMLGUIClient(parent)
 {
-	KopeteContactPtrList members = parent->members();
+	Kopete::ContactPtrList members = parent->members();
 	if( members.count() > 0 )
 	{
 		m_user = static_cast<IRCContact*>( members.first() );
