@@ -32,8 +32,8 @@ using namespace KIRC;
 void Engine::bindNumericReplies()
 {
 	bind(1, this, SLOT(numericReply_001(KIRC::Message &)), 1, 1);
-	bind(2, this, SLOT(numericReply_002(KIRC::Message &)), 1, 1); // incomingConnectString
-	bind(3, this, SLOT(numericReply_003(KIRC::Message &)), 1, 1); // incomingConnectString
+	bind(2, this, SLOT(numericReply_002(KIRC::Message &)), 1, 1);
+	bind(3, this, SLOT(numericReply_003(KIRC::Message &)), 1, 1);
 	bind(4, this, SLOT(numericReply_004(KIRC::Message &)), 5, 5);
 	bind(5, this, SLOT(numericReply_004(KIRC::Message &)), 1, 1);
 
@@ -48,33 +48,34 @@ void Engine::bindNumericReplies()
 	bind(265, this, SLOT(numericReply_265(KIRC::Message &)));
 	bind(266, this, SLOT(numericReply_266(KIRC::Message &)));
 
-	bind(301, this, SLOT(numericReply_301(KIRC::Message &)), 2, 2); // incomingUserIsAway
-	bind(303, this, SLOT(numericReply_303(KIRC::Message &)), 1, 1); // incomingUserOnline
-	bind(305, this, SLOT(ignoreMessage(KIRC::Message&)), 0, 0 ); // You are no longer marked as away
-	bind(306, this, SLOT(ignoreMessage(KIRC::Message&)), 0, 0 ); // You are marked as away
-	bind(307, this, SLOT(ignoreMessage(KIRC::Message&)), 0, 0 ); // DALNET: Nick is registered 
+	bind(301, this, SLOT(numericReply_301(KIRC::Message &)), 2, 2);
+	bind(303, this, SLOT(numericReply_303(KIRC::Message &)), 1, 1);
+	bind(305, this, SLOT(ignoreMessage(KIRC::Message &)), 0, 0 ); // You are no longer marked as away
+	bind(306, this, SLOT(ignoreMessage(KIRC::Message &)), 0, 0 ); // You are marked as away
+	bind(307, this, SLOT(numericReply_307(KIRC::Message &)), 1, 1);
 	bind(311, this, SLOT(numericReply_311(KIRC::Message &)), 5, 5);
 	bind(312, this, SLOT(numericReply_312(KIRC::Message &)), 3, 3);
-//	bind(313, this, SLOT(numericReply_313(KIRC::Message &)), 2, 2); // incomingWhoIsOperator
+	bind(313, this, SLOT(numericReply_313(KIRC::Message &)), 2, 2);
 	bind(314, this, SLOT(numericReply_314(KIRC::Message &)), 5, 5);
-	bind(315, this, SLOT(numericReply_315(KIRC::Message &)), 2, 2); //incomingEndOfWho
+	bind(315, this, SLOT(numericReply_315(KIRC::Message &)), 2, 2);
 	bind(317, this, SLOT(numericReply_317(KIRC::Message &)), 3, 4);
-	bind(318, this, SLOT(numericReply_318(KIRC::Message &)), 2, 2); // incomingEndOfWhois
+	bind(318, this, SLOT(numericReply_318(KIRC::Message &)), 2, 2);
 	bind(319, this, SLOT(numericReply_319(KIRC::Message &)), 2, 2);
-	bind(320, this, SLOT(numericReply_320(KIRC::Message &)), 2, 2); // incomingWhoIsIdentified
-//	bind(321, Engine::IgnoreMethod );
+	bind(320, this, SLOT(numericReply_320(KIRC::Message &)), 2, 2);
+	bind(321, this, SLOT(ignoreMessage(KIRC::Message &)), 0, 0 );
 	bind(322, this, SLOT(numericReply_322(KIRC::Message &)), 3, 3);
-	bind(323, this, SLOT(numericReply_323(KIRC::Message &)), 1, 1); // incomingEndOfList
+	bind(323, this, SLOT(numericReply_323(KIRC::Message &)), 1, 1);
 	bind(324, this, SLOT(numericReply_324(KIRC::Message &)), 2, 4);
 	bind(328, this, SLOT(numericReply_328(KIRC::Message &)), 2, 2);
 	bind(329, this, SLOT(numericReply_329(KIRC::Message &)), 3, 3);
+	bind(330, this, SLOT(ignoreMessage(KIRC::Message &)), 0, 0); // ???
 	bind(331, this, SLOT(numericReply_331(KIRC::Message &)), 2, 2);
 	bind(332, this, SLOT(numericReply_332(KIRC::Message &)), 2, 2);
 	bind(333, this, SLOT(numericReply_333(KIRC::Message &)), 4, 4);
 	bind(352, this, SLOT(numericReply_352(KIRC::Message &)), 5, 10);
 	bind(353, this, SLOT(numericReply_353(KIRC::Message &)), 3, 3);
-	bind(366, this, SLOT(numericReply_366(KIRC::Message &)), 2, 2); // incomingEndOfNames
-//	bind(369, this, SLOT(numericReply_369(KIRC::Message &)), 2, 2); // incomingEndOfWhoWas
+	bind(366, this, SLOT(numericReply_366(KIRC::Message &)), 2, 2);
+	bind(369, this, SLOT(numericReply_369(KIRC::Message &)), 2, 2);
 	bind(372, this, SLOT(numericReply_372(KIRC::Message &)), 1, 1);
 	bind(375, this, SLOT(ignoreMessage(KIRC::Message&)), 0, 0 );
 	bind(376, this, SLOT(ignoreMessage(KIRC::Message&)), 0, 0 );
@@ -82,6 +83,7 @@ void Engine::bindNumericReplies()
 	bind(401, this, SLOT(numericReply_401(KIRC::Message &)), 2, 2); // incomingNoNickChan
 //	bind(404, this, SLOT(numericReply_404(KIRC::Message &)), 2, 2); // incomingCannotSendToChannel
 	bind(406, this, SLOT(numericReply_406(KIRC::Message &)), 2, 2); // incomingWasNoNick
+	bind(422, this, SLOT(numericReply_422(KIRC::Message &)), 1, 1);
 	bind(433, this, SLOT(numericReply_433(KIRC::Message &)), 2, 2);
 //	bind(442, this, SLOT(numericReply_442(KIRC::Message &)), 2, 2); // incomingCannotSendToChannel
 	bind(464, this, SLOT(numericReply_464(KIRC::Message &)), 1, 1);
@@ -91,16 +93,7 @@ void Engine::bindNumericReplies()
 	bind(475, this, SLOT(numericReply_475(KIRC::Message &)), 2, 2);
 
 	//Freenode seems to use this for a non-RFC compliant purpose, as does Unreal
-	bind(477, this, SLOT(dumpSuffix(KIRC::Message&)),0,0);
-}
-
-/*
- * Use this for numeric codes that have multiple definitions, so we can't know what they are.
- * Dumps the message suffix to the screen
- */
-void Engine::dumpSuffix(KIRC::Message &msg)
-{
-	emit incomingUnknown(msg.suffix());
+	bind(477, this, SLOT(emitSuffix(KIRC::Message&)),0,0);
 }
 
 /* 001: "Welcome to the Internet Relay Network <nick>!<user>@<host>"
@@ -122,7 +115,7 @@ void Engine::numericReply_001(Message &msg)
 	/* At this point we are connected and the server is ready for us to being taking commands
 	 * although the MOTD comes *after* this.
 	 */
-	emit incomingConnectString(msg.suffix());
+	emitSuffix(msg);
 
 	setStatus(Connected);
 }
@@ -132,7 +125,7 @@ void Engine::numericReply_001(Message &msg)
  */
 void Engine::numericReply_002(Message &msg)
 {
-	emit incomingConnectString( msg.suffix() );
+	emitSuffix(msg);
 }
 
 /* 003: "This server was created <date>"
@@ -141,7 +134,7 @@ void Engine::numericReply_002(Message &msg)
  */
 void Engine::numericReply_003(Message &msg)
 {
-	emit incomingConnectString( msg.suffix() );
+	emitSuffix(msg);
 }
 
 /* 004: "<servername> <version> <available user modes> <available channel modes>"
@@ -265,12 +258,13 @@ void Engine::numericReply_303(Message &msg)
 // {
 // }
 
-/* 307:
+/* 307: ":is a registered nick"
  * DALNET: Indicates that this user is identified with NICSERV.
  */
-// void Engine::numericReply_307(Message &msg)
-// {
-// }
+void Engine::numericReply_307(Message & /*msg*/)
+{
+//	emit incomingWhoiIsUserNickIsRegistered(Kopete::Message::unescape(msg.arg(1)));
+}
 
 /* 311: "<nick> <user> <host> * :<real name>"
  * Show info about a user (part of a /whois) in the form of:
@@ -291,6 +285,9 @@ void Engine::numericReply_312(Message &msg)
 /* 313: "<nick> :is an IRC operator"
  * Show info about an operator (part of a /whois).
  */
+void Engine::numericReply_313(Message & /*msg*/)
+{
+}
 
 /* 314: "<nick> <user> <host> * :<real name>"
  * Show WHOWAS Info
@@ -453,13 +450,16 @@ void Engine::numericReply_366(Message &msg)
 /* 369:
  * End of WHOWAS Request
  */
+void Engine::numericReply_369(Message & /*msg*/)
+{
+}
 
 /* 372: ":- <text>"
  * Part of the MOTD.
  */
 void Engine::numericReply_372(Message &msg)
 {
-	emit incomingMotd( msg.suffix() );
+	emit incomingMotd(msg.suffix());
 }
 
 /* 375: ":- <server> Message of the day - "
@@ -487,6 +487,15 @@ void Engine::numericReply_406(Message &msg)
 	emit incomingNoSuchNickname( Kopete::Message::unescape(msg.arg(1)) );
 }
 
+/* 422: ":MOTD File is missing"
+ *
+ * Server's MOTD file could not be opened by the server.
+ */
+void Engine::numericReply_422(Message &msg)
+{
+	emit incomingMotd(msg.suffix());
+}
+
 /* 433: "<nick> :Nickname is already in use"
  * Tells us that our nickname is already in use.
  */
