@@ -53,7 +53,7 @@ Message::Message()
 }
 
 Message::Message(const Message &obj)
-	: m_ctcpMessage(0)
+        : QObject(), m_ctcpMessage(0)
 {
 	m_raw = obj.m_raw;
 
@@ -123,7 +123,7 @@ void Message::writeMessage(Engine *engine, const QTextCodec *codec,
 		msg += QChar(' ') + args.join(QChar(' ')).stripWhiteSpace(); // some extra check should be done here
 
 	if (!suffix.isNull())
-		msg += QString::fromLatin1(" :") + suffix;
+          msg = msg.stripWhiteSpace() + QString::fromLatin1(" :") + suffix;
 
 	writeMessage(engine, codec, msg);
 }
@@ -163,7 +163,17 @@ Message Message::parse(Engine *engine, const QTextCodec *codec, bool *parseSucce
 		if( length > -1 )
 		{
 			raw.resize( length );
-			raw.replace("\r\n",""); //remove the trailling \r\n if any(there must be in fact)
+
+			// Remove trailing '\r\n' or '\n'.
+			//
+			// Some servers send '\n' instead of '\r\n' that the RFCs say they should be sending.
+
+			if (length > 1 && raw.at(length-2) == '\n') {
+				raw.at(length-2) = '\0';
+			}
+			if (length > 2 && raw.at(length-3) == '\r') {
+				raw.at(length-3) = '\0';
+			}
 
 			kdDebug(14121) << "<< " << raw << endl;
 
@@ -203,10 +213,8 @@ QString Message::unquote(const QString &str)
 {
 	QString tmp = str;
 
-	char b[3];
-	b[0] = 20; b[1] = 20; b[2] = '\0';
-	char b2[2];
-	b2[0] = (char)20; b2[1] = '\0';
+	char b[3] = { 020, 020, '\0' };
+	const char b2[2] = { 020, '\0' };
 
 	tmp.replace( b, b2 );
 	b[1] = 'r';
@@ -240,7 +248,7 @@ bool Message::matchForIRCRegExp(const QCString &line, const QTextCodec *codec, M
 	if(matchForIRCRegExp(m_IRCCommandType1, codec, line, message))
 		return true;
 #ifdef _IRC_STRICTNESS_
-	if(!matchForIRCRegExp(m_IRCCommandType2, codec, line, message)
+	if(!matchForIRCRegExp(m_IRCCommandType2, codec, line, message))
 		return true;
 #endif // _IRC_STRICTNESS_
 	return false;
@@ -360,3 +368,5 @@ void Message::dump() const
 		m_ctcpMessage->dump();
 	}
 }
+
+#include "kircmessage.moc"
