@@ -1,7 +1,7 @@
 /*
     msneditaccountwidget.cpp - MSN Account Widget
 
-    Copyright (c) 2003      by Olivier Goffart       <ogoffart@tiscalinet.be>
+    Copyright (c) 2003      by Olivier Goffart       <ogoffart @ kde.org>
     Copyright (c) 2003      by Martijn Klingens      <klingens@kde.org>
 
     Kopete    (c) 2002-2003 by the Kopete developers <kopete-devel@kde.org>
@@ -28,6 +28,7 @@
 #include <qpushbutton.h>
 #include <qregexp.h>
 #include <qspinbox.h>
+#include <kcombobox.h>
 
 #include <kautoconfig.h>
 #include <kfiledialog.h>
@@ -39,16 +40,19 @@
 #include <kpassdlg.h>
 #include <krun.h>
 #include <kconfig.h>
+#include <kpixmapregionselectordialog.h>
 
 #include "kopeteuiglobal.h"
 #include "kopeteglobal.h"
 
 #include "kopetepasswordwidget.h"
+#include "kopeteaccountmanager.h"
 
 #include "msnaccount.h"
 #include "msncontact.h"
 #include "msneditaccountui.h"
 #include "msnnotifysocket.h"
+#include "msnprotocol.h"
 
 class MSNEditAccountWidgetPrivate
 {
@@ -56,6 +60,9 @@ public:
 	MSNProtocol *protocol;
 	KAutoConfig *autoConfig;
 	MSNEditAccountUI *ui;
+
+	QString pictureUrl;
+	QImage pictureData;
 };
 
 MSNEditAccountWidget::MSNEditAccountWidget( MSNProtocol *proto, Kopete::Account *account, QWidget *parent, const char * /* name */ )
@@ -71,7 +78,26 @@ MSNEditAccountWidget::MSNEditAccountWidget( MSNProtocol *proto, Kopete::Account
 
 	d->autoConfig = new KAutoConfig( d->ui );
 	d->autoConfig->addWidget( d->ui->global_settings_page, "MSN" );
+	d->autoConfig->addWidget( d->ui->privacy_page, "MSN" );
+	//the JabberAccount need to be saved as text, and can't be handled by kautoconfig
+	d->autoConfig->ignoreSubWidget( d->ui->JabberAccount );
 	d->autoConfig->retrieveSettings( true );
+	
+	//Get a list of all jabber accounts
+	KGlobal::config()->setGroup("MSN");
+	QString jab_account=KGlobal::config()->readEntry("JabberAccount");
+	
+	QPtrList<Kopete::Account>  accounts = Kopete::AccountManager::self()->accounts();
+	for(Kopete::Account *a=accounts.first() ; a; a=accounts.next() )
+	{
+		if(a->protocol()->pluginId()=="JabberProtocol")
+		{
+			d->ui->JabberAccount->insertItem(a->accountId());
+			if( jab_account.isEmpty() )
+				jab_account=a->accountId();
+		}
+	}
+	d->ui->JabberAccount->setCurrentText(jab_account);
 
 	// FIXME: actually, I don't know how to set fonts for qlistboxitem - Olivier
 	d->ui->label_font->hide();
@@ -90,7 +116,14 @@ MSNEditAccountWidget::MSNEditAccountWidget( MSNProtocol *proto, Kopete::Account
 		if ( ( static_cast<MSNAccount*>(account)->serverName() != "messenger.hotmail.com" ) || ( static_cast<MSNAccount*>(account)->serverPort() != 1863) ) {
 			d->ui->optionOverrideServer->setChecked( true );
 		}
+		
+		d->ui->m_webcamPort->setDisabled(true);
+		uint port=config->readNumEntry("WebcamPort" ,0);
+		d->ui->m_useWebcamPort->setChecked( port != 0);
+		d->ui->m_webcamPort->setValue( port != 0 ? port : 6891 );
 
+		d->ui->optionUseHttpMethod->setChecked( static_cast<MSNAccount*>(account)->useHttpMethod() );
+		
 		MSNContact *myself = static_cast<MSNContact *>( account->myself() );
 
 		d->ui->m_displayName->setText( myself->property( Kopete::Global::Properties::self()->nickName()).value().toString() );
@@ -125,8 +158,9 @@ MSNEditAccountWidget::MSNEditAccountWidget( MSNProtocol *proto, Kopete::Account
 
 		d->ui->m_blp->setChecked( config->readEntry( "BLP" ) == "BL" );
 
-		d->ui->m_displayPicture->setPixmap( locateLocal( "appdata", "msnpicture-" +
-			account->accountId().lower().replace( QRegExp("[./~]" ), "-" ) + ".png" ) );
+		d->pictureUrl = locateLocal( "appdata", "msnpicture-" +
+			account->accountId().lower().replace( QRegExp("[./~]" ), "-" ) + ".png" );
+		d->ui->m_displayPicture->setPixmap( d->pictureUrl );
 
 		d->ui->m_useDisplayPicture->setChecked( config->readBoolEntry( "exportCustomPicture" ));
 	}
@@ -137,11 +171,14 @@ MSNEditAccountWidget::MSNEditAccountWidget( MSNProtocol *proto, Kopete::Account
 		d->ui->m_phones->setDisabled( true );
 	}
 
-	connect( d->ui->m_allowButton, SIGNAL( pressed() ), this, SLOT( slotAllow() ) );
-	connect( d->ui->m_blockButton, SIGNAL( pressed() ), this, SLOT( slotBlock() ) );
-	connect( d->ui->m_selectImage, SIGNAL( pressed() ), this, SLOT( slotSelectImage() ) );
-	connect( d->ui->m_RLButton, SIGNAL( pressed() ), this, SLOT( slotShowReverseList() ) );
+	connect( d->ui->m_allowButton, SIGNAL( clicked() ), this, SLOT( slotAllow() ) );
+	connect( d->ui->m_blockButton, SIGNAL( clicked() ), this, SLOT( slotBlock() ) );
+	connect( d->ui->m_selectImage, SIGNAL( clicked() ), this, SLOT( slotSelectImage() ) );
+	connect( d->ui->m_RLButton, SIGNAL( clicked() ), this, SLOT( slotShowReverseList() ) );
 	connect( d->ui->buttonRegister, SIGNAL(clicked()), this, SLOT(slotOpenRegister()));
+	QWidget::setTabOrder( d->ui->m_login, d->ui->m_password->mRemembered );
+	QWidget::setTabOrder( d->ui->m_password->mRemembered, d->ui->m_password->mPassword );
+	QWidget::setTabOrder( d->ui->m_password->mPassword, d->ui->m_autologin );
 }
 
 MSNEditAccountWidget::~MSNEditAccountWidget()
@@ -152,6 +189,8 @@ MSNEditAccountWidget::~MSNEditAccountWidget()
 Kopete::Account * MSNEditAccountWidget::apply()
 {
 	d->autoConfig->saveSettings();
+	KGlobal::config()->setGroup("MSN");
+	KGlobal::config()->writeEntry("JabberAccount", d->ui->JabberAccount->currentText());
 
 	if ( !account() )
 		setAccount( new MSNAccount( d->protocol, d->ui->m_login->text() ) );
@@ -171,6 +210,29 @@ Kopete::Account * MSNEditAccountWidget::apply()
 		config->writeEntry( "serverPort", "1863" );
 	}
 
+	config->writeEntry( "useHttpMethod", d->ui->optionUseHttpMethod->isChecked() );
+	
+	if(d->ui->m_useWebcamPort->isChecked())
+		config->writeEntry( "WebcamPort" , d->ui->m_webcamPort->value() );
+	else
+		config->writeEntry( "WebcamPort" , 0 );
+
+	// Save the avatar image
+	if( d->ui->m_useDisplayPicture->isChecked() && !d->pictureData.isNull() )
+	{
+		d->pictureUrl = locateLocal( "appdata", "msnpicture-" +
+				account()->accountId().lower().replace( QRegExp("[./~]" ), "-" ) + ".png" );
+		if ( d->pictureData.save( d->pictureUrl, "PNG" ) )
+		{
+			static_cast<MSNAccount *>( account() )->setPictureUrl( d->pictureUrl );
+		}
+		else
+		{
+			KMessageBox::sorry( this, i18n( "<qt>An error occurred when trying to change the display picture.<br>"
+					"Make sure that you have selected a correct image file</qt>" ), i18n( "MSN Plugin" ) );
+		}
+	}
+
 	static_cast<MSNAccount *>( account() )->resetPictureObject();
 
 	if ( account()->isConnected() )
@@ -223,7 +285,7 @@ void MSNEditAccountWidget::slotAllow()
 	MSNNotifySocket *notify = static_cast<MSNAccount *>( account() )->notifySocket();
 	if ( !notify )
 		return;
-	notify->removeContact( handle, 0, MSNProtocol::BL );
+	notify->removeContact( handle, MSNProtocol::BL, QString::null, QString::null );
 
 	d->ui->m_BL->takeItem( item );
 	d->ui->m_AL->insertItem( item );
@@ -242,7 +304,7 @@ void MSNEditAccountWidget::slotBlock()
 	if ( !notify )
 		return;
 
-	notify->removeContact( handle, 0, MSNProtocol::AL );
+	notify->removeContact( handle, MSNProtocol::AL, QString::null, QString::null );
 
 	d->ui->m_AL->takeItem( item );
 	d->ui->m_BL->insertItem( item );
@@ -257,11 +319,6 @@ void MSNEditAccountWidget::slotShowReverseList()
 
 void MSNEditAccountWidget::slotSelectImage()
 {
-	// FIXME: the change will take effect immediately, even if the user presses cancel - Olivier
-	// FIXME: since we need the accountId to create the file HERE (and it's the problem) we need the account - Olivier
-	if ( !account() )
-		return;
-
 	QString path = 0;
 	bool remoteFile = false;
 	KURL filePath = KFileDialog::getImageOpenURL( QString::null, this, i18n( "MSN Display Picture" ) );
@@ -277,29 +334,15 @@ void MSNEditAccountWidget::slotSelectImage()
 	}
 	else path = filePath.path();
 
-	QString futurName = locateLocal( "appdata", "msnpicture-" + account()->accountId().lower().replace( QRegExp( "[./~]" ), "-" ) + ".png" );
-
 	QImage img( path );
+	img = KPixmapRegionSelectorDialog::getSelectedImage( QPixmap(img), 96, 96, this );
 
-	if(!img.isNull()) {
-		img = img.smoothScale( 96, 96, QImage::ScaleMax );
-		// crop image if not square
-		if(img.width() > img.height()) {
-			img = img.copy((img.width()-img.height())/2, 0, img.height(), img.height());
-		}
-		else if(img.height() > img.width()) {
-			img = img.copy(0, (img.height()-img.width())/2, img.width(), img.width());
-		}
-
-		if ( img.save( futurName, "PNG" ) )
+	if(!img.isNull()) 
 	{
-		d->ui->m_displayPicture->setPixmap( futurName );
-	}
-	else
-	{
-		KMessageBox::sorry( this, i18n( "<qt>An error occurred when trying to change the display picture.<br>"
-			"Make sure that you have selected a correct image file</qt>" ), i18n( "MSN Plugin" ) );
-	}
+		img = MSNProtocol::protocol()->scalePicture(img);
+	
+		d->ui->m_displayPicture->setPixmap( QPixmap(img) );
+		d->pictureData = img;
 	}
 	else
 	{
