@@ -23,18 +23,18 @@
 #include <qstring.h>
 
 class SMSAccount;
-class KopeteMessageManager;
-class KopeteMetaContact;
+namespace Kopete { class ChatSession; }
+namespace Kopete { class MetaContact; }
 
 class KActionCollection;
 class KAction;
 
-class SMSContact : public KopeteContact
+class SMSContact : public Kopete::Contact
 {
 	Q_OBJECT
 public:
-	SMSContact( KopeteAccount* _account, const QString &phoneNumber,
-		const QString &displayName, KopeteMetaContact *parent );
+	SMSContact( Kopete::Account* _account, const QString &phoneNumber,
+		const QString &displayName, Kopete::MetaContact *parent );
 
 	QPtrList<KAction>* customContextMenuActions();
 
@@ -48,30 +48,30 @@ public:
 	virtual void serialize( QMap<QString, QString> &serializedData,
 		QMap<QString, QString> &addressBookData );
 
-	KopeteMessageManager* manager( bool canCreate = false );
+	Kopete::ChatSession* manager( Kopete::Contact::CanCreateFlags canCreate = Kopete::Contact::CanCreate );
 
 public slots:
 	virtual void slotUserInfo();
-	virtual void slotDeleteContact();
-	void slotSendMessage(KopeteMessage &msg);
+	virtual void deleteContact();
+	void slotSendMessage(Kopete::Message &msg);
 
 private slots:
-	void slotSendingSuccess(const KopeteMessage &msg);
-	void slotSendingFailure(const KopeteMessage &msg, const QString &error);
+	void slotSendingSuccess(const Kopete::Message &msg);
+	void slotSendingFailure(const Kopete::Message &msg, const QString &error);
 
 signals:
 	void messageSuccess();
 
 private slots:
 	void userPrefs();
-	void slotMessageManagerDestroyed();
+	void slotChatSessionDestroyed();
 
 private:
 	KAction* m_actionPrefs;
 
 	QString m_phoneNumber;
 
-	KopeteMessageManager* m_msgManager;
+	Kopete::ChatSession* m_msgManager;
 };
 
 #endif
