@@ -26,51 +26,51 @@
 // Local Includes
 #include "wpcontact.h"
 #include "wpaccount.h"
-#include "wpdebug.h"
 
-WPContact::WPContact(Kopete::Account *account, const QString &newHostName, const QString &displayName, Kopete::MetaContact *metaContact)
+WPContact::WPContact(Kopete::Account *account, const QString &newHostName, const QString &nickName, Kopete::MetaContact *metaContact)
 	: Kopete::Contact(account, newHostName, metaContact)
 {
-	DEBUG(WPDMETHOD, "WPContact::WPContact(<account>, " << newHostName << ", " << displayName << ", <parent>)");
-	DEBUG(WPDINFO, "I am " << this << "!");
+//	kdDebug(14170) << "WPContact::WPContact(<account>, " << newHostName << ", " << nickName << ", <parent>)" << endl;
+	kdDebug(14170) << "I am " << this << "!" << endl;
 
-	QString newDisplayName;
-	for(unsigned i = 0; i < newHostName.length(); i++)
-		if(!i)
-			newDisplayName += newHostName[i].upper();
-		else
-			newDisplayName += newHostName[i].lower();
+	QString theNickName = nickName;
 
-	setDisplayName(displayName.isEmpty() ? newDisplayName : displayName);
+	if (theNickName.isEmpty()) {
+		// Construct nickname from hostname with first letter to upper. GF
+		theNickName = newHostName.lower();
+		theNickName = theNickName.replace(0, 1, theNickName[0].upper());
+	}
+
+	setNickName(theNickName);
 	myWasConnected = false;
 
 	// Initialise and start the periodical checking for contact's status
 	setOnlineStatus(static_cast<WPProtocol *>(protocol())->WPOffline);
-//	slotCheckStatus();
+
+	//TODO: makes checking more often than hostcheck cycle sense? GF
 	connect(&checkStatus, SIGNAL(timeout()), this, SLOT(slotCheckStatus()));
 	checkStatus.start(1000, false);
 
-	m_manager = 0L;
-	m_infoDialog = 0L;
+	m_manager = 0;
+	m_infoDialog = 0;
 }
 
 QPtrList<KAction> * WPContact::customContextMenuActions()
 {
 	//myActionCollection = new KActionCollection(parent);
-	return 0L;
+	return 0;
 }
 
 void WPContact::serialize(QMap<QString, QString> &serializedData, QMap<QString, QString> &addressBookData)
 {
-	kdDebug(14180) << "WP::serialize(...)" << endl;
+//	kdDebug(14170) << "WP::serialize(...)" << endl;
 
 	Kopete::Contact::serialize(serializedData, addressBookData);
 }
 
-Kopete::ChatSession* WPContact::manager( bool )	// TODO: use the parameter as canCreate
+Kopete::ChatSession* WPContact::manager( Kopete::Contact::CanCreateFlags /*canCreate*/ )	// TODO: use the parameter as canCreate
 {
-	if( !m_manager )
-	{
+	if (m_manager == 0) {
 		// Set up the message managers
 		QPtrList<Kopete::Contact> singleContact;
 		singleContact.append(this);
@@ -78,46 +78,42 @@ Kopete::ChatSession* WPContact::manager( bool )	// TODO: use the parameter as ca
 		m_manager = Kopete::ChatSessionManager::self()->create( account()->myself(), singleContact, protocol() );
 
 		connect(m_manager, SIGNAL(messageSent(Kopete::Message &, Kopete::ChatSession *)), this, SLOT(slotSendMessage(Kopete::Message &)));
-  		connect(m_manager, SIGNAL(messageSent(Kopete::Message &, Kopete::ChatSession *)), m_manager, SLOT(appendMessage(Kopete::Message &)));
+		connect(m_manager, SIGNAL(messageSent(Kopete::Message &, Kopete::ChatSession *)), m_manager, SLOT(appendMessage(Kopete::Message &)));
 		connect(m_manager, SIGNAL(destroyed()), this, SLOT(slotChatSessionDestroyed()));
 	}
 
 	return m_manager;
 }
+
 /*
 bool WPContact::isOnline() const
 {
-	kdDebug(14180) << "[WPContact::isOnline()]" << endl;
+	kdDebug(14170) << "[WPContact::isOnline()]" << endl;
 	return onlineStatus().status() != Kopete::OnlineStatus::Offline && onlineStatus().status() != Kopete::OnlineStatus::Unknown;
 }
 */
+
 bool WPContact::isReachable()
 {
-	kdDebug(14180) << "[WPContact::isReachable()]" << endl;
+//	kdDebug(14170) << "[WPContact::isReachable()]" << endl;
 	return onlineStatus().status() != Kopete::OnlineStatus::Offline && onlineStatus().status() != Kopete::OnlineStatus::Unknown;
 }
 
 void WPContact::slotChatSessionDestroyed()
 {
-	m_manager = 0L;
+	m_manager = 0;
 }
 
 void WPContact::slotUserInfo()
 {
-	// TODO: show user info?
-	kdDebug( 14180 ) << k_funcinfo << endl;
+	kdDebug( 14170 ) << k_funcinfo << endl;
 
-
-	if ( !m_infoDialog )
-	{
+	if (!m_infoDialog) {
 		m_infoDialog = new WPUserInfo( this, static_cast<WPAccount*>( account() ) );
-		if( !m_infoDialog )
-			return;
+		if (!m_infoDialog) return;
 		connect( m_infoDialog, SIGNAL( closing() ), this, SLOT( slotCloseUserInfoDialog() ) );
 		m_infoDialog->show();
-	}
-	else
-	{
+	} else {
 		m_infoDialog->raise();
 	}
 }
@@ -125,34 +121,43 @@ void WPContact::slotUserInfo()
 void WPContact::slotCloseUserInfoDialog()
 {
 	m_infoDialog->delayedDestruct();
-	m_infoDialog = 0L;
+	m_infoDialog = 0;
 }
 
+/*
 void deleteContact()
 {
 //	deleteLater();
 }
+*/
 
 void WPContact::slotCheckStatus()
 {
-//	DEBUG(WPDMETHOD, "WPContact::slotCheckStatus()");
-
 	bool oldWasConnected = myWasConnected;
 	bool newIsOnline = false;
 
 	myWasConnected = protocol() != 0 && account() != 0;
 	WPAccount *acct = dynamic_cast<WPAccount *>(account());
-	if (acct) {
-		newIsOnline = acct->checkHost(contactId());
-	}
+	if (acct) newIsOnline = acct->checkHost(contactId());
 
-	if(newIsOnline != isOnline() || myWasConnected != oldWasConnected)
-		setOnlineStatus(myWasConnected ? newIsOnline ? WPProtocol::protocol()->WPOnline : WPProtocol::protocol()->WPOffline : WPProtocol::protocol()->WPOffline );
+	if(newIsOnline != isOnline() || myWasConnected != oldWasConnected) {
+		Kopete::OnlineStatus tmpStatus;
+		if (myWasConnected) {
+			if (newIsOnline)
+				tmpStatus = WPProtocol::protocol()->WPOnline;
+			else
+				WPProtocol::protocol()->WPOffline;
+		} else {
+			WPProtocol::protocol()->WPOffline;
+		}
+
+		setOnlineStatus(tmpStatus);
+	}
 }
 
 void WPContact::slotNewMessage(const QString &Body, const QDateTime &Arrival)
 {
-	DEBUG(WPDMETHOD, "WPContact::slotNewMessage(" << Body << ", " << Arrival.toString() << ")");
+	kdDebug(14170) << "WPContact::slotNewMessage(" << Body << ", " << Arrival.toString() << ")" << endl;
 
 	QPtrList<Kopete::Contact> contactList;
 	contactList.append(account()->myself());
@@ -160,19 +165,20 @@ void WPContact::slotNewMessage(const QString &Body, const QDateTime &Arrival)
 	QRegExp subj("^Subject: ([^\n]*)\n(.*)$");
 	Kopete::Message msg;
 
-	if(subj.search(Body) == -1)
+	if(subj.search(Body) == -1) {
 		msg = Kopete::Message(this, contactList, Body, Kopete::Message::Inbound);
-	else
+	} else {
 		msg = Kopete::Message(this, contactList, subj.cap(2), subj.cap(1), Kopete::Message::Inbound);
+	}
 
-	manager()->appendMessage(msg);
+	manager(Kopete::Contact::CannotCreate)->appendMessage(msg);
 }
 
 void WPContact::slotSendMessage( Kopete::Message& message )
 {
-	DEBUG(WPDMETHOD, "WPContact::slotSendMessage(<message>)");
+//	kdDebug(14170) << "WPContact::slotSendMessage(<message>)" << endl;
 	// Warning: this could crash
-	DEBUG(WPDINFO, message.to().first() << " is " << dynamic_cast<WPContact *>( message.to().first() )->contactId() );
+	kdDebug(14170) << message.to().first() << " is " << dynamic_cast<WPContact *>( message.to().first() )->contactId() << endl;
 
 	QString Message = (!message.subject().isEmpty() ? "Subject: " + message.subject() + "\n" : QString("")) + message.plainBody();
 	WPAccount *acct = dynamic_cast<WPAccount *>(account());
@@ -185,3 +191,4 @@ void WPContact::slotSendMessage( Kopete::Message& message )
 
 #include "wpcontact.moc"
 
+// kate: tab-width 4; indent-width 4; replace-trailing-space-save on;
