@@ -53,15 +53,15 @@ namespace KPF
        * Only root dir specified - this causes an immediate loadConfig.
        *
        * @param root Virtual root directory for servers. Passed to all created
-       * Server objects, which much ensure that only files from the root and
-       * its child directories are served.
+       *             Server objects, which much ensure that only files from the root and
+       *             its child directories are served.
        */
       WebServer(const QString & root);
 
       /**
        * @param root Virtual root directory for servers. Passed to all created
-       * Server objects, which much ensure that only files from the root and
-       * its child directories are served.
+       *             Server objects, which much ensure that only files from the root and
+       *             its child directories are served.
        */
       WebServer
         (
@@ -69,7 +69,8 @@ namespace KPF
           uint             listenPort,
           uint             bandwidthLimit,
           uint             connectionLimit,
-          bool             followSymlinks
+          bool             followSymlinks,
+          const QString &  serverName
         );
 
       virtual ~WebServer();
@@ -88,6 +89,11 @@ namespace KPF
        */
       QString root();
 
+      /**
+       * @return server name
+       */
+      QString serverName();
+      
       /**
        * @return amount of bytes that may be sent out per second, in total
        * (adding the output of all contained Server objects.)
@@ -134,6 +140,11 @@ namespace KPF
        */
       void setListenPort          (uint);
 
+      /**
+       * Set server name
+       */
+      void setServerName          (const QString&);
+         
       /**
        * Set whether requests may include symbolic links in their path.
        */
@@ -153,7 +164,8 @@ namespace KPF
          uint   listenPort,
          ulong  bandwidthLimit,
          uint   connectionLimit,
-         bool   followSymlinks
+         bool   followSymlinks,
+	 const QString& serverName
         );
 
       /**
@@ -230,6 +242,12 @@ namespace KPF
        */
       void slotClearBacklog   ();
 
+      /**
+       * Called when this succesfully publishes via zeroconf, or there was an
+       * error doing so.
+       */
+      void wasPublished(bool ok);
+      
     protected:
 
       /**
@@ -308,6 +326,10 @@ namespace KPF
        */
       ulong bandwidthPerClient()  const;
 
+
+      /** publish this to dns-sd (zeroconf)
+       */
+      void publish();
       /**
        * Cause all existing Server objects to close their connections by
        * calling Server::cancel.
