@@ -1,7 +1,7 @@
 /*
  *           kPPP: A pppd front end for the KDE project
  *
- * $Id: accounts.cpp,v 1.76 2004/07/11 06:09:24 porten Exp $
+ * $Id: accounts.cpp 550636 2006-06-12 13:48:29Z mueller $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -41,6 +41,8 @@
 #include <kstdguiitem.h>
 #include <qvgroupbox.h>
 
+#include <errno.h>
+
 #include "pppdata.h"
 #include "accounts.h"
 #include "accounting.h"
@@ -211,8 +213,12 @@ void AccountWidget::viewLogClicked(){
 
     QApplication::flushX();
     if(fork() == 0) {
-      setgid(getgid());
+      if (setgid(getgid()) < 0 && errno != EPERM)
+        _exit(2);
       setuid(getuid());
+      if( geteuid() != getuid() )
+        _exit(1);
+      // TODO: use execvp
       system("kppplogview -kppp");
       _exit(0);
     }
@@ -432,14 +438,14 @@ QueryReset::QueryReset(QWidget *parent) : QDialog(parent, 0, true) {
   costs->setChecked(true);
   l1->addWidget(costs);
   QWhatsThis::add(costs, i18n("Check this to set the phone costs\n"
-			      "to zero. Typically you'll want to\n"
+			      "to zero. Typically you will want to\n"
 			      "do this once a month."));
 
   volume = new QCheckBox(i18n("Reset &volume accounting"), f);
   volume->setChecked(true);
   l1->addWidget(volume);
   QWhatsThis::add(volume, i18n("Check this to set the volume accounting\n"
-			       "to zero. Typically you'll want to do this\n"
+			       "to zero. Typically you will want to do this\n"
 			       "once a month."));
 
   l1->activate();
