@@ -2,7 +2,7 @@
  *
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: ppplog.cpp 384595 2005-01-31 15:49:00Z coles $
+ * $Id: ppplog.cpp 437911 2005-07-23 14:56:02Z binner $
  *
  * (c) 1998 Mario Weilguni <mweilguni@kde.org>
  *
@@ -216,7 +216,7 @@ void PPPL_ShowLog() {
 				     "that pppd was started without the \"debug\" option.\n"
 				     "Without this option it's difficult to find out PPP "
 				     "problems, so you should turn on the debug option.\n"
-				     "Shall I turn it on now?"));
+				     "Shall I turn it on now?"), QString::null, i18n("Restart pppd"), i18n("Do Not Restart"));
 
     if(result == KMessageBox::Yes) {
       gpppdata.setPPPDebug(TRUE);
