@@ -21,6 +21,7 @@
 #include "hostpreferences.h"
 
 #include <kapplication.h>
+#include <kconfig.h>
 #include <kdebug.h>
 #include <kcombobox.h>
 #include <kurl.h>
@@ -185,6 +186,8 @@ bool KRDC::start()
 			break;
 	}
 
+	m_view->setViewOnly(kapp->config()->readBoolEntry("viewOnly", false));
+
 	m_scrollView->addChild(m_view);
 	QWhatsThis::add(m_view, i18n("Here you can see the remote desktop. If the other side allows you to control it, you can also move the mouse, click or enter keystrokes. If the content does not fit your screen, click on the toolbar's full screen button or scale button. To end the connection, just close the window."));
 
@@ -290,8 +293,8 @@ bool KRDC::parseHost(QString &str, Protocol &prot, QString &serverHost, int &ser
 	password = QString::null;
 
 	if (prot == PROTOCOL_AUTO) {
-		if(s.startsWith("smb://")>0) {  //we know it's more likely to be windows..
-			s = "rdp://" + s.section("smb://", 1);
+		if(s.startsWith("smb:/")>0) {  //we know it's more likely to be windows..
+			s = "rdp:/" + s.section("smb:/", 1);
 			prot = PROTOCOL_RDP;
 		} else if(s.contains("://") > 0) {
 			s = s.section("://",1);
@@ -553,10 +556,6 @@ void KRDC::switchToNormal(bool scaling)
 		m_oldResolution = Resolution();
 	}
 
-	if (m_popup) {
-		m_popup->deleteLater();
-		m_popup = 0;
-	}
 	if (m_fsToolbar) {
 		m_fsToolbar->hide();
 		m_fsToolbar->deleteLater();
@@ -595,6 +594,11 @@ void KRDC::switchToNormal(bool scaling)
 		QWhatsThis::add(skButton, i18n("This option allows you to send special key combinations like Ctrl-Alt-Del to the remote host."));
 		t->addConnection(2, SIGNAL(clicked()), m_keyCaptureDialog, SLOT(execute()));
 
+		if (m_popup) {
+			m_popup->deleteLater();
+			m_popup = 0;
+		}
+
 		m_popup = createPopupMenu(t);
 		t->insertButton("configure", 3, m_popup, true, i18n("Advanced"));
 		KToolBarButton *advancedButton = t->getButton(3);
