@@ -13,6 +13,10 @@
 #include "page_colorsbase.h"
 #include "ksopts.h"
 
+#include <qlistbox.h>
+#include <qstringlist.h>
+#include <qdict.h>
+
 class PageColors : public PageColorsBase
 {
 Q_OBJECT
@@ -28,8 +32,22 @@ public:
 protected slots:
     void changed();
 
+public slots:
+    virtual void theme_clicked(QListBoxItem*);
+    virtual void themeNewPB_clicked();
+    virtual void themeAddPB_clicked();
+    virtual void themeDelPB_clicked();
+    virtual void theme_sel();
+
 signals:
     void modified();
+
+private:
+    void coloursSetEnable();
+
+private:
+    int changing;
+    QDict<KSOColors> m_dcol;
 };
 
 #endif
