@@ -1,5 +1,5 @@
 #
-# $$Id: ksirc.pl 390325 2005-02-17 18:10:02Z aseigo $$
+# $$Id: ksirc.pl 393633 2005-02-27 21:03:15Z staikos $$
 #
 
 &addhelp("server",
@@ -552,7 +552,7 @@ sub hook_fixcolours {
 
 sub cmd_dishighlight {
     
-    print "*I* Hightlight parsing: ";
+    print "*I* Highlight parsing: ";
     if($k_highlight == 0) {
         $k_highlight = 1;
         print "Enabled\n";
@@ -567,7 +567,7 @@ sub cmd_dishighlight {
         close(FH);
     }
     else {
-        print "*E* Can't save highlgiht state $!\n";
+        print "*E* Can't save highlight state $!\n";
     }
 
 }
@@ -577,7 +577,7 @@ sub cmd_dishighlight {
          "Toggles the convertion of *bold* into \cbbold\cb\n" .
          "and _underline_ into \c_underline\c_ and #reverse#\n" .
          "into \cvreverse\cv.  It saves the state into\n" .
-         "~/.ksirc_highlight for conveniance");
+         "~/.ksirc_highlight for convenience");
 
 sub cmd_help {
   &tell("*\cbH\cb* Help not available"), return unless @help;
