@@ -179,21 +179,6 @@ void KSOptions::load( int sections )
     if ( sections & Startup )
     {
 	conf->setGroup( "StartUp" );
-/*
-	nick = conf->readEntry( "Nick", nick );
-	altNick = conf->readEntry( "AlternativeNick", altNick );
-	realName = conf->readEntry( "RealName", realName );
-	userID = conf->readEntry( "userID", userID );
-        if ( !conf->hasKey( "NotifyList" ) && conf->hasGroup( "NotifyList" ) )
-        {
-            conf->setGroup( "NotifyList" );
-            int count = conf->readNumEntry( "Number" );
-            for ( int i = 0; i < count; ++i )
-                notifyList.append( conf->readEntry(
-                    QString::fromLatin1( "Notify-%1" ).arg( i ) ) );
-        }
-	notifyList = conf->readListEntry( "NotifyList" );
-        */
     }
 
 
@@ -342,9 +327,6 @@ void KSOptions::load( int sections )
 	    server["global"].realName = conf->readEntry("RealName");
 	    server["global"].userID = conf->readEntry("userID");
 	    server["global"].notifyList = conf->readListEntry("NotifyList");
-	    if(server["global"].notifyList.count() == 0){
-		server["global"].notifyList = conf->readListEntry("NotifyList");
-	    }
 
 	    conf->setGroup( "Server" );
 	}
@@ -364,7 +346,7 @@ void KSOptions::load( int sections )
 	    ksos.realName = conf->readEntry(*ser + "realName");
 	    ksos.userID = conf->readEntry(*ser + "userID");
 	    ksos.notifyList = conf->readListEntry(*ser + "notifyList");
-	    kdDebug() << *ser << ": nick: " << ksos.nick << " altNick: " << ksos.altNick << endl;
+	    kdDebug(5008) << *ser << ": nick: " << ksos.nick << " altNick: " << ksos.altNick << endl;
 	    server.insert(*ser, ksos);
 	}
     }
