@@ -16,7 +16,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: ksview.cpp 321172 2004-06-16 12:44:49Z waba $
+// $Id: ksview.cpp 393645 2005-02-27 22:05:39Z staikos $
 
 #include <qclipboard.h>
 #include <qdatetime.h>
@@ -31,6 +31,7 @@
 #include <krun.h>
 #include <kpopupmenu.h>
 #include <kstringhandler.h>
+#include <knotifyclient.h>
 #include <kfiledialog.h>
 #include <kio/job.h>
 #include <kurldrag.h>
@@ -197,6 +198,11 @@ QString KSircView::addLine(const QString &pixmap, const QColor &color, const QSt
         }
     }
 
+    if (parser.beeped()) {
+        KNotifyClient::event(winId(), QString::fromLatin1("BeepReceived"),
+                        i18n("Beep Received"));
+    }
+
     QString logText = parag.plainText();
     // append timestamp if it's not already there
     if ( ! m_timestamps )
