@@ -2,7 +2,7 @@
 
  Server Controller
 
- $$Id: servercontroller.cpp 291519 2004-02-26 08:12:31Z dfaure $$
+ $$Id: servercontroller.cpp 402276 2005-03-31 21:19:22Z woebbe $$
 
  Main Server Controller.  Displays server connection window, and makes
  new server connection on demand.
@@ -539,7 +539,7 @@ void servercontroller::ProcMessage(QString server, int command, QString args)
         // include the \0, so we need to copy one more. -1 + 1 = 0.
 	memmove(old_s, old_s+1, strlen(old_s));
       if(new_s[0] == '!')
-	memmove(new_s, new_s, strlen(new_s)); // See above for strlen()
+	memmove(new_s, new_s+1, strlen(new_s)); // See above for strlen()
 
       item = findChild( serverItem, old_s );
       delete item;
