@@ -88,7 +88,7 @@ class TalkConnection
     int get_sockt() { return sockt; }
     /** Returns response answer and id_num. Allows protocol independence.
      * Each param can be null (0L). Then it isn't filled.*/
-    void getResponseItems(u_int8_t * answer, u_int32_t * id_num, struct talk_addr * addr);
+    void getResponseItems(uint8_t * answer, uint32_t * id_num, struct talk_addr * addr);
     /** Returns connection socket address. For FWT. */
     const struct talk_addr get_addr() { return new_msg.addr; } // idem in old_msg
 
