@@ -70,7 +70,7 @@ NEW_CTL_MSG * KTalkdTable::find_match(NEW_CTL_MSG *request)
     for (ptr = table; ptr != NIL; ptr = ptr->next) {
         if ((ptr->time - current_time) > MAX_LIFE) {
             /* the entry is too old */
-            debug("deleting expired entry : id %d",
+            ktalk_debug("deleting expired entry : id %d",
                      ptr->request.id_num);
             delete_entry(ptr);
             continue;
@@ -79,7 +79,7 @@ NEW_CTL_MSG * KTalkdTable::find_match(NEW_CTL_MSG *request)
             (strcmp(request->r_name, ptr->request.l_name) == 0) &&
             (ptr->request.type == LEAVE_INVITE) && (ptr->fwm == 0L))
         {   /* Not the forw. machines : they aren't stored to match LOOK_UPs */
-            debug("Found match : id %d", ptr->request.id_num);
+            ktalk_debug("Found match : id %d", ptr->request.id_num);
             return (&ptr->request);
         }
     }
@@ -104,7 +104,7 @@ NEW_CTL_MSG * KTalkdTable::find_request(NEW_CTL_MSG *request)
     for (ptr = table; ptr != NIL; ptr = ptr->next) {
         if ((ptr->time - current_time) > MAX_LIFE) {
             /* the entry is too old */
-            debug("deleting expired entry : id %d",
+            ktalk_debug("deleting expired entry : id %d",
                      ptr->request.id_num);
             delete_entry(ptr);
             continue;
@@ -115,7 +115,7 @@ NEW_CTL_MSG * KTalkdTable::find_request(NEW_CTL_MSG *request)
             request->pid == ptr->request.pid) {
             /* update the time if we 'touch' it */
             ptr->time = current_time;
-            debug("Found identical request : id %d", ptr->request.id_num);
+            ktalk_debug("Found identical request : id %d", ptr->request.id_num);
             return (&ptr->request);
         }
     }
@@ -130,7 +130,7 @@ void KTalkdTable::insert_table(NEW_CTL_MSG *request, NEW_CTL_RESPONSE *response,
     gettimeofday(&tp, &txp);
     current_time = tp.tv_sec;
     request->id_num = new_id();
-    debug("Stored as id %d",request->id_num);
+    ktalk_debug("Stored as id %d",request->id_num);
     if (response != 0L) response->id_num = htonl(request->id_num);
     /* insert a new entry into the top of the list */
     ptr = new TABLE_ENTRY;
@@ -165,12 +165,12 @@ int KTalkdTable::new_id()
 /*
  * Delete the invitation with id 'id_num'
  */
-int KTalkdTable::delete_invite(u_int32_t id_num)
+int KTalkdTable::delete_invite(uint32_t id_num)
 {
     register TABLE_ENTRY *ptr;
 
     ptr = table;
-    debug("delete_invite(%d)", id_num);
+    ktalk_debug("delete_invite(%d)", id_num);
     for (ptr = table; ptr != NIL; ptr = ptr->next) {
         if (ptr->request.id_num == id_num)
             break;
@@ -179,7 +179,7 @@ int KTalkdTable::delete_invite(u_int32_t id_num)
         if (ptr->fwm) {
             ptr->fwm->sendDelete(); // Calls processDelete() in the child process.
         }
-        debug("Deleted : id %d", ptr->request.id_num);
+        ktalk_debug("Deleted : id %d", ptr->request.id_num);
         delete_entry(ptr);
         return (SUCCESS);
     }
@@ -204,14 +204,14 @@ KTalkdTable::~KTalkdTable()
 {
       register TABLE_ENTRY *ptr;
       ptr = table;
-      debug("final_clean()");
+      ktalk_debug("final_clean()");
       for (ptr = table; ptr != 0L; ptr = ptr->next) {
           if (ptr->fwm != 0L)
           {
-              debug("CLEAN : Found a forwarding machine to clean : id %d",ptr->request.id_num);
+              ktalk_debug("CLEAN : Found a forwarding machine to clean : id %d",ptr->request.id_num);
               delete ptr->fwm;
           }
-          debug("CLEAN : Deleting id %d", ptr->request.id_num);
+          ktalk_debug("CLEAN : Deleting id %d", ptr->request.id_num);
           delete_entry(ptr);
       }
 }
