@@ -24,6 +24,7 @@
 #include <kio/tcpslavebase.h>
 #include <kio/global.h>
 
+#include <qvaluevector.h>
 #include <qcstring.h>
 #include <qstring.h>
 #include <qdict.h>
@@ -38,18 +39,20 @@
 #define KIOLAN_FISH 4
 #define KIOLAN_MAX 5
 
+#define NAMELEN 8
+
 struct MyProtocolInfo
 {
    int enabled;
-   int port;
+   QValueVector<int> ports;
    //this should be large enough for things like "FTP" and so on
-   char name[8];
+   char name[NAMELEN];
 };
 
 struct HostInfo
 {
    time_t created;
-   int ports[KIOLAN_MAX];
+   int services[KIOLAN_MAX];
 };
 
 class LANProtocol : public KIO::TCPSlaveBase
@@ -71,13 +74,14 @@ class LANProtocol : public KIO::TCPSlaveBase
       int lanReadDataFromServer();
       int rlanReadDataFromServer();
       int checkHost(const QString& host);
-      int checkPort(int _port, in_addr ip);
+      int checkPort(QValueVector<int>& _ports, in_addr ip);
       QString m_currentHost;
       unsigned short int m_port;
       MyProtocolInfo m_protocolInfo[KIOLAN_MAX];
       int m_maxAge;
       bool m_isLanIoslave;
       bool m_shortHostnames;
+      QString m_defaultLisaHost;
 };
 
 #endif
