@@ -16,8 +16,9 @@
 #ifndef NETSCANNER_H
 #define NETSCANNER_H
 
+#include <list>
+
 #include "mystring.h"
-#include "simplelist.h"
 #include "addressvalidator.h"
 #include "tcpnode.h"
 #include "configfile.h"
@@ -26,6 +27,8 @@
 #include <stdlib.h>
 #include <sys/wait.h>
 #include <sys/types.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
 #include <time.h>
 
 #include <arpa/inet.h>
@@ -37,7 +40,6 @@
 
 #include <stdio.h>
 
-
 class NetScanner
 {
    public:
@@ -46,9 +48,9 @@ class NetScanner
 
       void doScan();
 
-      void completeNames(SimpleList<Node>* nodes);
+      void completeNames(std::list<Node>* nodes);
       
-      //mit nmblookup ip-adresse aus netbios namen ermitteln
+      //using nmblookup to determine the ip-address
       //MyString ip2NetbiosName(const MyString& target, MyString& groupName);
       
       char* ip2Name(struct in_addr ip);
@@ -71,20 +73,30 @@ class NetScanner
       //with all ip-addresses according to ipRangeStr
       struct in_addr getIPfromArray(unsigned int index);
 
-      SimpleList<Node>* hostList;
+      std::list<Node>* hostList;
 
       //needed for getIPfromArray()
       //contains the part of ipRangeStr, which is not yet parsed
       MyString tmpIPRange;
-      //has to be called befor every first call of getNextIPRange
+      //has to be called before every first call of getNextIPRange
       void resetIPRange();
-      //returns the next range/part from tmpIPRange befor the next semicolon
+      //returns the next range/part from tmpIPRange before the next semicolon
       MyString getNextIPRange();
 
-      void pingScan(SimpleList<Node>* newList);   //the ping-version
-      void nmblookupScan(SimpleList<Node>* newList); //the nmblookup "*"-version
-      int hostAlreadyInList(int ip, SimpleList<Node>* nodes);
-      void removeUnnamedHosts(SimpleList<Node>* nodes);
+      void pingScan(std::list<Node>* newList);   //the ping-version
+      void nmblookupScan(std::list<Node>* newList); //the nmblookup "*"-version
+      int hostAlreadyInList(int ip, std::list<Node>* nodes);
+      void removeUnnamedHosts(std::list<Node>* nodes);
+
+      struct is_unnamed_node : std::unary_function<Node&, bool>
+      {
+         bool operator() (Node& n)
+         {
+            struct in_addr tmpAddr;
+            tmpAddr.s_addr = n.ip;
+            return (strcmp(inet_ntoa(tmpAddr), n.name.data()) == 0);
+         }
+      };
 };
 
 #endif
