@@ -33,6 +33,7 @@
 #include <iostream>
 #include <string>
 #include <klocale.h>
+#include <kstandarddirs.h>
 #include <kprocio.h>
 #include <kdebug.h>
 #include <qstring.h>
@@ -524,7 +525,13 @@ QTable* Interface_wireless_wirelessextensions::get_available_networks ()
     networks->horizontalHeader()->setLabel( 3, i18n("WEP") );
 
     KProcIO *iwlist = new KProcIO;
-    *iwlist << "iwlist" << interface_name << "scanning";
+    QString iwlist_bin = KStandardDirs::findExe("iwlist");
+    if(iwlist_bin.isEmpty())
+      iwlist_bin = KStandardDirs::findExe("iwlist", "/usr/local/sbin:/usr/sbin:/sbin");
+    if(iwlist_bin.isEmpty())
+      iwlist_bin = "iwlist"; // try our best ;/
+
+    *iwlist << iwlist_bin << interface_name << "scanning";
 
     connect ( iwlist, SIGNAL ( readReady ( KProcIO * ) ), this, SLOT ( parseScanData ( KProcIO * ) ) );
 	    
@@ -543,7 +550,8 @@ void
 Interface_wireless_wirelessextensions::parseScanData ( KProcIO * iwlist )
 {
   QString data;
-  int cellcount;
+  int cellcount = 0, iteratecount = 0;
+  bool ignoreRemainingBits = false;
   while ( iwlist->readln ( data, true ) >= 0 )
     {
       kdDebug (  ) << "iwlist: " << data << "\n";
@@ -557,6 +565,7 @@ Interface_wireless_wirelessextensions::parseScanData ( KProcIO * iwlist )
       if ( data.contains ( "Cell" ) ) {
         cellcount++;            // new cell discovered
 	networks->setNumRows ( networks->numRows() +1 );
+	ignoreRemainingBits = false;
       }
       if ( data.contains ( "ESSID:" ) )
         {
@@ -570,20 +579,46 @@ Interface_wireless_wirelessextensions::parseScanData ( KProcIO * iwlist )
             networks->setText ( cellcount - 1, 1, QString ( i18n ( "Managed" ) ) );
           if ( data.contains ( "Ad-Hoc" ) )
             networks->setText ( cellcount - 1, 1, QString ( i18n ( "Ad-Hoc" ) ) );
+	  // if could be that this cell belongs to an SSID already discovered, or that there are more than one
+	  // hidden cells, which doesn't give any new information. So, we first search for duplicates and delete 
+	  // this row if it's a duplicate. If the same SSID is there once as Managed and once as Ad-Hoc it is no
+	  // duplicate of course, but "something completely different"
+	  for (iteratecount = 0; iteratecount < cellcount - 1; iteratecount++)
+	  {
+	      kdDebug() << "Comparing <" << networks->text(cellcount - 1, 0) << "," << networks->text(iteratecount,0) << " and <"
+		        << networks->text(cellcount - 1, 1) << "," << networks->text(iteratecount,1) << ">.\n";
+	      if ((networks->text(cellcount - 1 , 0) == networks->text(iteratecount,0)) &&
+	          (networks->text(cellcount - 1 , 1) == networks->text(iteratecount,1)) )
+	      {
+	           networks->setNumRows ( networks->numRows() - 1 );
+	           cellcount--;
+		   ignoreRemainingBits = true;
+	      }
+	  }
         }
-      if ( data.contains ( "Encryption key:" ) )
+      if ( !ignoreRemainingBits && data.contains ( "Encryption key:" ) )
         {
           if ( data.contains ( "on" ) )
             networks->setText ( cellcount - 1, 3, QString ( "on" ) );
           else
             networks->setText ( cellcount - 1, 3, QString ( "off" ) );
         }
-      if ( data.contains ( "Quality:" ) )
+      if ( !ignoreRemainingBits && data.contains ( "Quality:" ) )
         {
           QString quality = data.mid ( data.find ( ":" ) + 1, data.find ( "/" ) - data.find ( ":" ) - 1 );
           networks->setText ( cellcount - 1, 2, quality );
         }
 
+      if ( !ignoreRemainingBits && data.contains ( "wpa_ie" ) )
+	{
+	  networks->setText ( cellcount - 1, 3, QString ( "WPA" ) );
+	}
+      
+      if ( !ignoreRemainingBits && data.contains ( "rsn_ie" ) )
+        {
+          networks->setText ( cellcount - 1, 3, QString ( "WPA2" ) );
+        }
+      
     }
 }
 
