@@ -1,5 +1,5 @@
 /***************************************************************************
-                          stuff.h  -  description
+                          interface_wireless_wirelessextensions.h  -  description
                              -------------------
     begin                : Mon Aug 19 2002
     copyright            : (C) 2002 by Stefan Winter
@@ -21,7 +21,7 @@
 #include "config.h"
 
 #include <qstring.h>
-#include <qstringlist.h>
+#include <qtable.h>
 
 #ifndef WITHOUT_ARTS
 #include <arts/iomanager.h>
@@ -30,6 +30,9 @@
 
 #include "interface_wireless.h"
 
+class QTable;
+class KProcIO;
+
 extern "C"
 {
 #include <iwlib.h>
@@ -39,7 +42,7 @@ class Interface_wireless_wirelessextensions:public Interface_wireless
 {
 Q_OBJECT public:
   Interface_wireless_wirelessextensions (QStringList * ignoreInterfaces);
-  QStringList get_available_networks ();
+  QTable* get_available_networks ();
 
 public:
   void setActiveDevice( QString device );
@@ -55,6 +58,9 @@ private:
 
   QString print_scanning_token (struct iw_event *event);
   int get_info (int skfd, const QString& interface, struct wireless_info& info);
+  QTable* networks;
+private slots:
+  void parseScanData ( KProcIO * iwlist );
 };
 
 #endif /*  INTERFACE_WIRELESS_WIRELESSEXTENSIONS_H */
