@@ -19,7 +19,7 @@ public:
     LinuxWireLessWidget(QWidget *parent=0, const char* name=0);
     ~LinuxWireLessWidget();
 protected:
-    /* poll() is supposed to read the information from
+    /** poll() is supposed to read the information from
        /proc/net/wireless (Linux) and put it into the data members. */
     void poll();
     static int socketFD; // the socket file descriptor to talk to the
@@ -29,6 +29,8 @@ protected:
                               char *	ifname,
                               char *	args[],
                               int	count);
+    /** Store previously found number of wireless devices. */
+    int m_number;
 };
 
 #endif
