@@ -39,6 +39,8 @@ PropertiesDialog::PropertiesDialog(QWidget *parent, const char *name)
     table = new PropertyTable(this);
     setMainWidget(table);
     table->table->setLeftMargin(0);
+    table->table->setSorting(false);
+    table->table->setReadOnly(true);
     adjustSize();
     timer = new QTimer(this);
     connect(timer, SIGNAL(timeout()), SLOT(timeout()));
